@@ -2,8 +2,8 @@
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """Lightweight :term:`computation` graphs for Python."""
 
-__version__ = "10.1.0"
-__release_date__ = "5 Aug 2020, 14:02"
+__version__ = "10.2.0"
+__release_date__ = "16 Aug 2020, 12:15"
 __title__ = "graphtik"
 __summary__ = __doc__.splitlines()[0]
 __license__ = "Apache-2.0"
@@ -25,7 +25,7 @@ from .modifier import (
     varargs,
 )
 from .fnop import NO_RESULT, NO_RESULT_BUT_SFX, operation
-from .pipeline import NULL_OP, compose
+from .pipeline import compose
 
 ## SEE ALSO: `.plot.active_plotter_plugged()`, `.plot.set_active_plotter()` &
 #  `.plot.get_active_plotter()` configs, not imported, unless plot is needed..
