@@ -143,6 +143,21 @@ def astuple(i, argname, allowed_types=tuple):
     return i
 
 
+def asset(i, argname, allowed_types=set):
+    if not i:
+        return i if isinstance(i, allowed_types) else set()
+
+    if isinstance(i, str):
+        i = {i}
+    elif not isinstance(i, allowed_types):
+        try:
+            i = set(i)
+        except Exception as ex:
+            raise ValueError(f"Cannot set-ize {argname}({i!r}) due to: {ex}") from None
+
+    return i
+
+
 def func_name(
     fn, default=..., mod=None, fqdn=None, human=None, partials=None
 ) -> Optional[str]:
@@ -227,9 +242,7 @@ def func_name(
     except Exception as ex:
         if default is ...:
             raise
-        log.debug(
-            "Ignored error while inspecting %r name: %s", fn, ex,
-        )
+        log.debug("Ignored error while inspecting %r name: %s", fn, ex)
         return default
 
 
@@ -268,9 +281,7 @@ def func_source(fn, default=..., human=None) -> Optional[Tuple[str, int]]:
     except Exception as ex:
         if default is ...:
             raise
-        log.debug(
-            "Ignored error while inspecting %r sources: %s", fn, ex,
-        )
+        log.debug("Ignored error while inspecting %r sources: %s", fn, ex)
         return default
 
 
@@ -290,9 +301,7 @@ def func_sourcelines(fn, default=..., human=None) -> Optional[Tuple[str, int]]:
     except Exception as ex:
         if default is ...:
             raise
-        log.debug(
-            "Ignored error while inspecting %r sourcelines: %s", fn, ex,
-        )
+        log.debug("Ignored error while inspecting %r sourcelines: %s", fn, ex)
         return default
 
 
@@ -606,6 +615,7 @@ class Plottable(abc.ABC):
             digraph pipeline {
             fontname=italic;
             label=<pipeline>;
+            node [fillcolor=white, style=filled];
             <a> [fillcolor=wheat, fixedsize=shape, label=<<TABLE CELLBORDER="0" CELLSPACING="0" BORDER="0">
             ...
 
@@ -758,12 +768,24 @@ class Operation(Plottable, abc.ABC):
 
     name: str
     needs: Items
-    op_needs: Items
     provides: Items
-    op_provides: Items
+
+    def __eq__(self, other):
+        """Operation identity is based on `name`."""
+        return bool(self.name == getattr(other, "name", other))
+
+    def __hash__(self):
+        """Operation identity is based on `name`."""
+        return hash(self.name)
 
     @abc.abstractmethod
-    def compute(self, named_inputs, outputs=None):
+    def compute(
+        self,
+        named_inputs,
+        outputs=None,
+        recompute_from=None,
+        *kw,
+    ):
         """
         Compute (optional) asked `outputs` for the given `named_inputs`.
 
@@ -772,6 +794,13 @@ class Operation(Plottable, abc.ABC):
 
         :param named_inputs:
             the input values with which to feed the computation.
+        :param outputs:
+            what results to compute,
+            see :meth:`.Pipeline.compute()`.
+        :param recompute_from:
+            recompute all downstream from those dependencies,
+            see :meth:`.Pipeline.compute()`.
+
         :returns list:
             Should return a list values representing
             the results of running the feed-forward computation on
@@ -783,7 +812,7 @@ class Operation(Plottable, abc.ABC):
     #     raise NotImplementedError("Operation subclasses")
 
     def _rename_graph_names(
-        self, kw, renamer: Union[Callable[[RenArgs], str], Mapping[str, str]],
+        self, kw, renamer: Union[Callable[[RenArgs], str], Mapping[str, str]]
     ) -> None:
         """
         Pass operation & dependency names through `renamer`.
