@@ -9,7 +9,7 @@ from collections import ChainMap, abc, defaultdict, namedtuple
 from contextvars import ContextVar, copy_context
 from functools import partial
 from itertools import chain
-from typing import Any, Collection, List, Mapping, Optional, Tuple, Union
+from typing import Any, Callable, Collection, List, Mapping, Optional, Tuple, Union
 
 import networkx as nx
 from boltons.setutils import IndexedSet as iset
@@ -75,7 +75,14 @@ class Solution(ChainMap, Plottable):
     for each operation executed, +1 for the user inputs.
     """
 
-    def __init__(self, plan, input_values: dict, layered_solution=None):
+    def __init__(
+        self,
+        plan,
+        input_values: dict,
+        pre_callback: Callable[["OpCb"], None] = None,
+        layered_solution=None,
+    ):
+        self.pre_callback = pre_callback
         layered_solution = first_solid(is_layered_solution(), layered_solution)
         if layered_solution is None:
             layered_solution = not any(get_jsonp(d) for d in plan.net.data)
@@ -88,9 +95,11 @@ class Solution(ChainMap, Plottable):
         #:
         #: If network contains :term:`jsonp` dependencies, by default
         #: layers are disabled, and this is None.
-        self._layers: Optional[Mapping] = {
-            op: {} for op in yield_ops(reversed(plan.steps))
-        } if layered_solution else None
+        self._layers: Optional[Mapping] = (
+            {op: {} for op in yield_ops(reversed(plan.steps))}
+            if layered_solution
+            else None
+        )
         maps = self._layers.values() if self._layers else ()
         super().__init__(*maps, input_values)
 
@@ -127,10 +136,21 @@ class Solution(ChainMap, Plottable):
         self.dag = plan.dag.copy()
         # assert next(iter(dag.edges))[0] == next(iter(plan.dag.edges))[0]:
 
-    def __copy__(self):
-        clone = type(self)(self.plan, {})
+    def copy(self):
+        """Deep-copy user's `input_data` and pass the rest intoa new Solution. """
+        named_inputs = dict(self.maps[-1])
+        clone = type(self)(
+            self.plan,
+            named_inputs,
+            self.pre_callback,
+            # Specially handled below bc user's `layered_solution` arg is lost.
+            layered_solution=None,
+        )
+        if self._layers is None:
+            clone._layers = None
+
         props = (
-            "maps executed canceled elapsed_ms solid _layers"
+            "maps executed canceled elapsed_ms solid"
             " is_endurance is_reschedule is_parallel is_marshal dag"
         ).split()
         for p in props:
@@ -138,6 +158,8 @@ class Solution(ChainMap, Plottable):
 
         return clone
 
+    __copy__ = copy
+
     def __repr__(self):
         if is_debug():
             return self.debugstr()
@@ -255,7 +277,7 @@ class Solution(ChainMap, Plottable):
         self._update_op_outs(op, outputs)
         self.executed[op] = None
 
-        if first_solid(self.is_reschedule, op.rescheduled):
+        if first_solid(self.is_reschedule, getattr(op, "rescheduled", None)):
             ## Find which provides have been broken?
             #
             # OPTIMIZE: could use _fn_provides
@@ -364,13 +386,14 @@ class _OpTask:
     This intermediate class is needed to solve pickling issue with process executor.
     """
 
-    __slots__ = ("op", "sol", "solid", "result")
+    __slots__ = ("op", "sol", "solid", "pre_callback", "result")
     logname = __name__
 
-    def __init__(self, op, sol, solid, result=UNSET):
+    def __init__(self, op, sol, solid, pre_callback=None, result=UNSET):
         self.op = op
         self.sol = sol
         self.solid = solid
+        self.pre_callback = pre_callback
         self.result = result
 
     def marshalled(self):
@@ -385,6 +408,8 @@ class _OpTask:
             log.debug("+++ (%s) Executing %s...", self.solid, self)
             token = task_context.set(self)
             try:
+                if self.pre_callback:
+                    self.pre_callback(OpCb(self.op, self.sol, self.solid))
                 self.result = self.op.compute(self.sol)
             finally:
                 task_context.reset(token)
@@ -401,8 +426,8 @@ class _OpTask:
         return f"OpTask({self.op}, sol_keys={sol_items!r})"
 
 
-#: Populated with the :class:`_OpTask` for the currently executing operation.
-#: It does not work for :term:`parallel execution`.
+#: (unstable API) Populated with the :class:`_OpTask` for the currently executing operation.
+#: It does not work for (deprecated) :term:`parallel execution`.
 #:
 #: .. seealso::
 #:     The elaborate example in :ref:`hierarchical-data` section
@@ -430,8 +455,17 @@ def _do_task(task):
     return result
 
 
+#: Argument passed in a :term:`pre_callback` callable before executing each operation,
+#: and contains fields to identify the operation call:
+#:
+#: :param op: the operation about to be computed;
+#: :param sol: the slution (might be just a plain dict if it has been marshalled);
+#: :param solid: the operation identity, needed if `sol` is a plain dict,
+OpCb = namedtuple("OpCb", "op, sol, solid")
+
+
 class ExecutionPlan(
-    namedtuple("ExecPlan", "net needs provides dag steps asked_outs comments"),
+    namedtuple("ExecPlan", "net needs provides dag steps asked_outs comments"),  # noqa
     Plottable,
 ):
     """
@@ -534,7 +568,7 @@ class ExecutionPlan(
             raise ValueError(
                 f"Unsolvable graph:\n  +--{self.net}"
                 f"\n  +--possible inputs: {list(self.net.needs)}"
-                "\n  +--possible outputs: {list(self.net.provides)}"
+                f"\n  +--possible outputs: {list(self.net.provides)}"
             )
 
         if inputs is UNSET:
@@ -587,11 +621,11 @@ class ExecutionPlan(
                 # Mark start time here, to include also marshalling overhead.
                 solution.elapsed_ms[op] = time.time()
 
-                task = _OpTask(op, input_values, solution.solid)
-                if first_solid(global_marshal, op.marshalled):
+                task = _OpTask(op, input_values, solution.solid, solution.pre_callback)
+                if first_solid(global_marshal, getattr(op, "marshalled", None)):
                     task = task.marshalled()
 
-                if first_solid(global_parallel, op.parallel):
+                if first_solid(global_parallel, getattr(op, "parallel", None)):
                     if not pool:
                         raise RuntimeError(
                             "With `parallel` you must `set_execution_pool().`"
@@ -641,7 +675,9 @@ class ExecutionPlan(
                 "... (%s) op(%s) completed in %sms.", solution.solid, op.name, elapsed
             )
         except Exception as ex:
-            is_endured = first_solid(solution.is_endurance, op.endured)
+            is_endured = first_solid(
+                solution.is_endurance, getattr(op, "endured", None)
+            )
             elapsed = elapsed_ms(op)
             loglevel = logging.WARNING if is_endured else logging.ERROR
             log.log(
@@ -669,7 +705,7 @@ class ExecutionPlan(
 
     def _execute_thread_pool_barrier_method(self, solution: Solution):
         """
-        This method runs the graph using a parallel pool of thread executors.
+        (deprecated)  This method runs the graph using a parallel pool of thread executors.
         You may achieve lower total latency if your graph is sufficiently
         sub divided into operations using this method.
 
@@ -769,7 +805,7 @@ class ExecutionPlan(
                 if step in solution.canceled:
                     continue
 
-                task = _OpTask(step, solution, solution.solid)
+                task = _OpTask(step, solution, solution.solid, solution.pre_callback)
                 self._handle_task(task, step, solution)
 
             elif isinstance(step, str):
@@ -792,6 +828,7 @@ class ExecutionPlan(
         outputs=None,
         *,
         name="",
+        pre_callback: Callable[[OpCb], None] = None,
         solution_class=None,
         layered_solution=None,
     ) -> Solution:
@@ -806,6 +843,9 @@ class ExecutionPlan(
             and scream if not.
         :param name:
             name of the pipeline used for logging
+        :param pre_callback:
+            If given, the :term:`pre_callback` is called before each operation,
+            with that as argument and solution.
         :param solution_class:
             a custom solution factory to use
         :param layered_solution:
@@ -839,7 +879,7 @@ class ExecutionPlan(
             ## Choose a method of execution
             #
             in_parallel = is_parallel_tasks() or any(
-                op.parallel for op in yield_ops(self.steps)
+                getattr(op, "parallel", None) for op in yield_ops(self.steps)
             )
             executor = (
                 self._execute_thread_pool_barrier_method
@@ -861,6 +901,7 @@ class ExecutionPlan(
                 {k: v for k, v in named_inputs.items() if k in dag.nodes}
                 if evict
                 else named_inputs,
+                pre_callback,
                 layered_solution=layered_solution,
             )
 
@@ -896,7 +937,7 @@ class ExecutionPlan(
             if evict:
                 expected_provides = set()
                 expected_provides.update(
-                    yield_chaindocs(dag, self.provides, expected_provides,)
+                    yield_chaindocs(dag, self.provides, expected_provides)
                 )
                 expected_provides = set(dep_stripped(n) for n in expected_provides)
                 # It is a proper subset when not all outputs calculated.
