@@ -9,7 +9,6 @@
     (<5ms on a 2019 fast PC)
 """
 
-import itertools as itt
 import logging
 import textwrap
 import sys
@@ -133,9 +132,7 @@ def jsonp_ize_all(deps):
 
 def reparse_operation_data(
     name, needs, provides, aliases=()
-) -> Tuple[
-    str, Collection[str], Collection[str], Collection[Tuple[str, str]],
-]:
+) -> Tuple[str, Collection[str], Collection[str], Collection[Tuple[str, str]]]:
     """
     Validate & reparse operation data as lists.
 
@@ -203,8 +200,8 @@ def _spread_sideffects(
     Build fn/op dependencies by stripping/singularizing any :term:`implicit`/:term:`sideffects`.
 
     :return:
-        the given `deps` duplicated as ``(op_deps, fn_deps)``, where any instances of
-        :term:`sideffects` are processed like this:
+        a x2 tuple ``(op_deps, fn_deps)``, where any instances of
+        :term:`sideffects` in `deps` are processed like this:
 
         `op_deps`
             - any :func:`.sfxed` is replaced by a sequence of ":func:`singularized
@@ -218,7 +215,6 @@ def _spread_sideffects(
               they are first met.  In particular, it replaces any :func:`.sfxed`
               by the :func:`stripped <.dep_stripped>`, unless ...
             - it had been declared as :term:`implicit`, in which case, it is discared;
-            - discards all the rest duplicate `sideffected` dependencies;
             - any :func:`.sfx` are simply dropped.
     """
 
@@ -241,9 +237,9 @@ def _spread_sideffects(
     assert deps is not None
 
     if deps:
-        deps = tuple(nn for n in deps for nn in dep_singularized(n))
+        op_deps = iset(nn for n in deps for nn in dep_singularized(n))
         fn_deps = tuple(nn for n in deps for nn in strip_unique(n))
-        return deps, fn_deps
+        return op_deps, fn_deps
     else:
         return deps, deps
 
@@ -261,21 +257,28 @@ class FnOp(Operation):
 
     Differences between various dependency operation attributes:
 
-    +--------------------------+-----+-----+-----+--------+
-    |   dependency attribute   |dupes|sfx  |alias|  SFXED |
-    +==========+===============+=====+=====+=====+========+
-    |          |  **needs**    ||yes|||yes||     |SINGULAR|
-    +          +---------------+-----+-----+     +--------+
-    | *needs*  | **op_needs**  ||no| ||yes||     |SINGULAR|
-    +          +---------------+-----+-----+     +--------+
-    |          |  *_fn_needs*  ||yes|||no| |     |STRIPPED|
-    +----------+---------------+-----+-----+-----+--------+
-    |          | **provides**  ||yes|||yes|||no| |SINGULAR|
-    +          +---------------+-----+-----+-----+--------+
-    |*provides*|**op_provides**||no| ||yes|||yes||SINGULAR|
-    +          +---------------+-----+-----+-----+--------+
-    |          |*_fn_provides* ||yes|||no| ||no| |STRIPPED|
-    +----------+---------------+-----+-----+-----+--------+
+
+    +-----------------------------+-----+-----+-----+--------+
+    |   dependency attribute      |dupes| sfx |alias|  sfxed |
+    +==========+==================+=====+=====+=====+========+
+    |          |    **needs**     ||no| ||yes||     |SINGULAR|
+    +          +------------------+-----+-----+     +--------+
+    | *needs*  | **_user_needs**  ||yes|||yes||     |        |
+    +          +------------------+-----+-----+     +--------+
+    |          |   *_fn_needs*    ||yes|||no| |     |STRIPPED|
+    +----------+------------------+-----+-----+-----+--------+
+    |          |   **provides**   ||no| ||yes|||yes||SINGULAR|
+    +          +------------------+-----+-----+-----+--------+
+    |*provides*|**_user_provides**||yes|||yes|||no| |        |
+    +          +------------------+-----+-----+-----+--------+
+    |          |  *_fn_provides*  ||yes|||no| ||no| |STRIPPED|
+    +----------+------------------+-----+-----+-----+--------+
+
+    where:
+
+    - "dupes=no" means the collection drops any duplicated dependencies
+    - "SINGULAR" means ``sfxed('A', 'a', 'b') ==> sfxed('A', 'b'), sfxed('A', 'b')``
+    - "STRIPPED" means ``sfxed('A', 'a', 'b') ==> sfx('a'), sfxed('b')``
 
     .. |yes| replace:: :green:`✓`
     .. |no| replace:: :red:`✗`
@@ -322,11 +325,11 @@ class FnOp(Operation):
             name, needs, provides, aliases
         )
 
+        user_needs, user_provides = needs, provides
         needs, _fn_needs = _spread_sideffects(needs)
         provides, _fn_provides = _spread_sideffects(provides)
-        op_needs = iset(needs)
         alias_dst = aliases and tuple(dst for _src, dst in aliases)
-        op_provides = iset(itt.chain(provides, alias_dst))
+        provides = iset((*provides, *alias_dst))
 
         # TODO: enact conveyor fn if varargs in the outputs.
         if fn is None and name and len(_fn_needs) == len(_fn_provides):
@@ -361,33 +364,28 @@ class FnOp(Operation):
             qname = ".".join((*qname.split(".")[:-1], name))
         self.__qualname__ = qname
 
-        #: The :term:`needs` almost as given by the user
-        #: (which may contain MULTI-sideffecteds and dupes),
-        #: roughly morphed into `_fn_provides` + sideffects
-        #: (DUPES, SFX, SINGULARIZED :term:`sideffected`\s).
-        #: It is stored for builder functionality to work.
-        self.needs = needs
-        #: Value names ready to lay the graph for :term:`pruning`
+        #: Dependencies ready to lay the graph for :term:`pruning`
         #: (NO-DUPES, SFX, SINGULAR :term:`sideffected`\s).
-        self.op_needs = op_needs
+        self.needs = needs
+        #: The :term:`needs` as given by the user, stored for *builder pattern*
+        #: to work.
+        self._user_needs = user_needs
         #: Value names the underlying function requires
         #: (DUPES preserved, NO-SFX, STRIPPED :term:`sideffected`).
         self._fn_needs = _fn_needs
 
-        #: The :term:`provides` almost as given by the user
-        #: (which may contain MULTI-sideffecteds and dupes),
-        #: roughly morphed into `_fn_provides` + sideffects
-        #: (DUPES, NO-ALIASES, SFX, SINGULAR :term:`sideffected`\s).
-        #: It is stored for builder functionality to work.
-        self.provides = provides
         #: Value names ready to lay the graph for :term:`pruning`
-        #: (NO DUPES, ALIASES, SFX, SINGULAR sideffecteds).
-        self.op_provides = op_provides
+        #: (NO DUPES, ALIASES, SFX, SINGULAR sideffecteds, +alias destinations).
+        self.provides = provides
+        #: The :term:`provides` as given by the user, stored for *builder pattern*
+        #: to work.
+        self._user_provides = user_provides
         #: Value names the underlying function produces
         #: (DUPES, NO-ALIASES, NO_SFX, STRIPPED :term:`sideffected`).
         self._fn_provides = _fn_provides
+
         #: an optional mapping of `fn_provides` to additional ones, together
-        #: comprising this operations :term:`op_provides`.
+        #: comprising this operations the `provides`.
         #:
         #: You cannot alias an :term:`alias`.
         self.aliases = aliases
@@ -399,11 +397,11 @@ class FnOp(Operation):
         #: If true, even if *callable* fails, solution will :term:`reschedule`;
         #: ignored if :term:`endurance` enabled globally.
         self.endured = endured
-        #: execute in :term:`parallel`
+        #: execute in (deprecated) :term:`parallel`
         self.parallel = parallel
         #: If true, operation will be :term:`marshalled <marshalling>` while computed,
         #: along with its `inputs` & `outputs`.
-        #: (usefull when run in `parallel` with a :term:`process pool`).
+        #: (usefull when run in (deprecated) `parallel` with a :term:`process pool`).
         self.marshalled = marshalled
         #: If true, it means the underlying function :term:`returns dictionary` ,
         #: and no further processing is done on its results,
@@ -411,23 +409,15 @@ class FnOp(Operation):
         #:
         #: It does not have to return any :term:`alias` `outputs`.
         #:
-        #: Can be changed amidst execution by the operation's function,
-        #: but it is easier for that function to simply call :meth:`.set_results_by_name()`.
+        #: Can be changed amidst execution by the operation's function.
         self.returns_dict = returns_dict
         #: Added as-is into NetworkX graph, and you may filter operations by
         #: :meth:`.Pipeline.withset()`.
         #: Also plot-rendering affected if they match `Graphviz` properties,
+        #: if they start with :data:`.USER_STYLE_PREFFIX`,
         #: unless they start with underscore(``_``).
         self.node_props = node_props
 
-    def __eq__(self, other):
-        """Operation identity is based on `name`."""
-        return bool(self.name == getattr(other, "name", UNSET))
-
-    def __hash__(self):
-        """Operation identity is based on `name`."""
-        return hash(self.name)
-
     def __repr__(self):
         """
         Display operation & dependency names annotated with :term:`diacritic`\\s.
@@ -442,7 +432,7 @@ class FnOp(Operation):
         )
 
         dep_names = (
-            "needs op_needs _fn_needs provides op_provides _fn_provides aliases"
+            "needs _user_needs _fn_needs provides _user_provides _fn_provides aliases"
             if is_debug()
             else "needs provides aliases"
         ).split()
@@ -469,25 +459,15 @@ class FnOp(Operation):
     @property
     def deps(self) -> Mapping[str, Collection]:
         """
-        All :term:`dependency` names, including `op_` & internal `_fn_`.
+        All :term:`dependency` names, including internal `_user_` & `_fn_`.
 
         if not DEBUG, all deps are converted into lists, ready to be printed.
         """
         from .config import is_debug
 
         return {
-            k: v if is_debug() else list(v)
-            for k, v in zip(
-                "needs op_needs fn_needs provides op_provides fn_provides".split(),
-                (
-                    self.needs,
-                    self.op_needs,
-                    self._fn_needs,
-                    self.provides,
-                    self.op_provides,
-                    self._fn_provides,
-                ),
-            )
+            k: getattr(self, k) if is_debug() else list(getattr(self, k))
+            for k in "needs _user_needs fn_needs provides _user_provides fn_provides".split()
         }
 
     def withset(
@@ -549,7 +529,7 @@ class FnOp(Operation):
             ...                     "B-aliased": "new.B-aliased"})
             FnOp(name='BAR',
                                 needs=['A'],
-                                provides=['B', sfx('cc')],
+                                provides=['B', sfx('cc'), 'new.B-aliased'],
                                 aliases=[('B', 'new.B-aliased')],
                                 fn='str')
 
@@ -568,7 +548,7 @@ class FnOp(Operation):
             ...            False)
             FnOp(name='foo',
                                 needs=['parent.a'],
-                                provides=['parent.b', sfx('parent.c')],
+                                provides=['parent.b', sfx('parent.c'), 'parent.B-aliased'],
                                 aliases=[('parent.b', 'parent.B-aliased')],
                                 fn='str')
 
@@ -578,19 +558,20 @@ class FnOp(Operation):
 
             dep_renamed(ren_args.name, f"parent.{dependency(ren_args.name)}")
         """
-        kw = {
+        kwargs = {
             k: v
             for k, v in locals().items()
             if v is not ... and k not in "self renamer".split()
         }
         ## Exclude calculated dep-fields.
         #
-        me = {
-            k: v
-            for k, v in vars(self).items()
-            if not k.startswith("_") and not k.startswith("op_")
+        me = {k: v for k, v in vars(self).items() if not k.startswith("_")}
+        kw = {
+            **me,
+            "needs": self._user_needs,
+            "provides": self._user_provides,
+            **kwargs,
         }
-        kw = {**me, **kw}
 
         if renamer:
             self._rename_graph_names(kw, renamer)
@@ -607,7 +588,7 @@ class FnOp(Operation):
             )
 
     def _prepare_match_inputs_error(
-        self, missing: List, varargs_bad: List, named_inputs: Mapping,
+        self, missing: List, varargs_bad: List, named_inputs: Mapping
     ) -> ValueError:
         from .config import is_debug
 
@@ -665,9 +646,7 @@ class FnOp(Operation):
                 ok = True
             finally:
                 if not ok:
-                    log.error(
-                        "Failed while preparing op(%s) need(%s)!", self.name, n,
-                    )
+                    log.error("Failed while preparing op(%s) need(%s)!", self.name, n)
 
         if missing or varargs_bad:
             msg = self._prepare_match_inputs_error(missing, varargs_bad, named_inputs)
@@ -722,9 +701,7 @@ class FnOp(Operation):
         missmatched = fn_required - res_names
         if missmatched:
             if is_rescheduled:
-                log.warning(
-                    "... Op %r did not provide%s", self.name, list(missmatched),
-                )
+                log.warning("... Op %r did not provide%s", self.name, list(missmatched))
             else:
                 raise ValueError(
                     f"Got x{len(results)} results({list(results)}) mismatched "
@@ -834,7 +811,15 @@ class FnOp(Operation):
 
         return results
 
-    def compute(self, named_inputs=None, outputs: Items = None) -> dict:
+    def compute(self, named_inputs=None, outputs: Items = None, *args, **kw) -> dict:
+        """
+        :param named_inputs:
+            a :class:`.Solution` instance
+        :param args:
+            ignored -- to comply with superclass contract
+        :param kw:
+            ignored -- to comply with superclass contract
+        """
         ok = False
         try:
             self.validate_fn_name()
@@ -957,7 +942,7 @@ def operation(
             - :term:`needs`
             - :term:`modifier`
             - :attr:`.FnOp.needs`
-            - :attr:`.FnOp.op_needs`
+            - :attr:`.FnOp._user_needs`
             - :attr:`.FnOp._fn_needs`
 
 
@@ -984,7 +969,7 @@ def operation(
             - :term:`provides`
             - :term:`modifier`
             - :attr:`.FnOp.provides`
-            - :attr:`.FnOp.op_provides`
+            - :attr:`.FnOp._user_provides`
             - :attr:`.FnOp._fn_provides`
 
 
@@ -999,10 +984,10 @@ def operation(
         If true, even if *callable* fails, solution will :term:`reschedule`.
         ignored if :term:`endurance` enabled globally.
     :param parallel:
-        execute in :term:`parallel`
+        (deprecated) execute in :term:`parallel`
     :param marshalled:
         If true, operation will be :term:`marshalled <marshalling>` while computed,        along with its `inputs` & `outputs`.
-        (usefull when run in `parallel` with a :term:`process pool`).
+        (usefull when run in (deprecated) `parallel` with a :term:`process pool`).
     :param returns_dict:
         if true, it means the `fn` :term:`returns dictionary` with all `provides`,
         and no further processing is done on them
