@@ -36,7 +36,7 @@ import pandas as pd
 
 
 log = logging.getLogger(__name__)
-UNSET = ...  # Change this in case of troubles...
+UNSET = "%%UNSET%%"  # Change this in case of troubles...
 
 
 def escape_jsonpointer_part(part: str) -> str:
@@ -110,7 +110,7 @@ class ResolveError(KeyError):
 
     def __str__(self):
         return (
-            f"Failed resolving step (#{self.index}){self.part} of json pointer path {self.path!r}."
+            f'Failed resolving step (#{self.index}) "{self.part}" of path {self.path!r}.'
             "\n  Check debug logs."
         )
 
@@ -144,7 +144,7 @@ def resolve_path(
     path: Union[str, Iterable[str]],
     default=UNSET,
     root=UNSET,
-    descend_objects=None,
+    descend_objects=True,
 ):
     """
     Resolve *roughly like* a json-pointer `path` within the referenced `doc`.
@@ -210,8 +210,7 @@ def resolve_path(
 
         >>> resolve_path(dt, '/pi/BAD')
         Traceback (most recent call last):
-        ...
-        graphtik.jsonpointer.ResolveError: Failed resolving step (#2)BAD of json pointer path '/pi/BAD'.
+        graphtik.jsonpointer.ResolveError: Failed resolving step (#2) "BAD" of path '/pi/BAD'.
           Check debug logs.
 
 
@@ -226,7 +225,7 @@ def resolve_path(
         *((getattr,) if descend_objects else ()),
     ]
 
-    if root is ...:
+    if root is UNSET:
         root = doc
 
     parts = jsonp_path(path) if isinstance(path, str) else path
@@ -239,25 +238,26 @@ def resolve_path(
             doc = root
             continue
 
-        for indexer in part_indexers:
+        for ii, indexer in enumerate(part_indexers):
             try:
                 doc = indexer(doc, part)
                 break
             except Exception as ex:
-                log.debug(
-                    "indexer %s failed on step (#%i)%s of json-pointer(%r) with doc(%s), due to: %s ",
-                    indexer,
-                    i,
-                    part,
-                    path,
-                    doc,
-                    ex,
-                    # Don't log int(part) stack-traces.
-                    exc_info=type(ex) is not ValueError
-                    or not str(ex).startswith("invalid literal for int()"),
-                )
+                if ii > 0:  # ignore int-indexing
+                    log.debug(
+                        "indexer %s failed on step (#%i)%s of json-pointer(%r) with doc(%s), due to: %s ",
+                        indexer,
+                        i,
+                        part,
+                        path,
+                        doc,
+                        ex,
+                        # Don't log int(part) stack-traces.
+                        exc_info=type(ex) is not ValueError
+                        or not str(ex).startswith("invalid literal for int()"),
+                    )
         else:
-            if default is ...:
+            if default is UNSET:
                 raise ResolveError(path, part, i)
 
             return default
@@ -269,7 +269,7 @@ def contains_path(
     doc: Union[Sequence, Mapping],
     path: Union[str, Iterable[str]],
     root=UNSET,
-    descend_objects=None,
+    descend_objects=True,
 ) -> bool:
     """Test if `doc` has a value for json-pointer path by calling :func:`.resolve_path()`. """
     try:
@@ -361,7 +361,7 @@ def set_path_value(
     value,
     container_factory=dict,
     root=UNSET,
-    descend_objects=None,
+    descend_objects=True,
 ):
     """
     Resolve a ``jsonpointer`` within the referenced ``doc``.
@@ -403,7 +403,7 @@ def set_path_value(
         *((object_scouter,) if descend_objects else ()),
     ]
 
-    if root is ...:
+    if root is UNSET:
         root = doc
 
     parts = jsonp_path(path) if isinstance(path, str) else list(path)
@@ -424,26 +424,27 @@ def set_path_value(
             fact = container_factory
             overwrite = False
 
-        for scouter in part_scouters:
+        for ii, scouter in enumerate(part_scouters):
             try:
                 doc = scouter(doc, part, fact, overwrite)
                 break
             except Exception as ex:
-                log.debug(
-                    "scouter %s failed on step (#%i)%s of json-pointer(%r) with doc(%s), due to: %s",
-                    scouter,
-                    i,
-                    part,
-                    path,
-                    doc,
-                    ex,
-                    # Don't log int(part) stack-traces.
-                    exc_info=type(ex) is not ValueError
-                    or not str(ex).startswith("invalid literal for int()"),
-                )
+                if ii > 0:  # ignore int-indexing
+                    log.debug(
+                        "scouter %s failed on step (#%i)%s of json-pointer(%r) with doc(%s), due to: %s",
+                        scouter,
+                        i,
+                        part,
+                        path,
+                        doc,
+                        ex,
+                        # Don't log int(part) stack-traces.
+                        exc_info=type(ex) is not ValueError
+                        or not str(ex).startswith("invalid literal for int()"),
+                    )
         else:
             raise ValueError(
-                f"Failed setting step (#{i}){part} of json pointer path {path!r}!"
+                f'Failed setting step (#{i}) "{part}" of path {path!r}!'
                 "\n  Check debug logs."
             )
 
@@ -453,17 +454,17 @@ def _update_paths(
     paths_vals: Collection[Tuple[List[str], Any]],
     container_factory=dict,
     root=UNSET,
-    descend_objects=None,
+    descend_objects=True,
 ) -> None:
     # The `group` is a list of paths with common prefix (root)
     # currently being built.
     group_prefix, group = None, ()
-    for p, v in paths_vals + [((...,), ...)]:
-        assert len(p) >= 1 or v is ..., locals()
+    for p, v in paths_vals + [((UNSET,), UNSET)]:
+        assert len(p) >= 1 or v is UNSET, locals()
 
         next_prefix = p[0]
         if next_prefix != group_prefix:
-            if len(p) == 1 and v is not ...:
+            if len(p) == 1 and v is not UNSET:
                 # Assign value and proceed to the next one,
                 # THOUGH if a deeper path with this same prefix follows,
                 # it will overwrite the value just written.
@@ -479,7 +480,7 @@ def _update_paths(
                             child = None
                             _log_overwrite(group_prefix, doc, child)
 
-                    if not child:
+                    if child is None:
                         child = doc[group_prefix] = container_factory()
                     _update_paths(child, [(p[1:], v) for p, v in group])
 
@@ -494,7 +495,7 @@ def update_paths(
     paths_vals: Collection[Tuple[str, Any]],
     container_factory=dict,
     root=UNSET,
-    descend_objects=None,
+    descend_objects=True,
 ) -> None:
     paths_vals = sorted(paths_vals)
     _update_paths(
@@ -529,7 +530,7 @@ def pop_path(
     path: Union[str, Iterable[str]],
     default=UNSET,
     root=UNSET,
-    descend_objects=None,
+    descend_objects=True,
 ):
     """
     Delete and return the item referenced by json-pointer `path` from the nested `doc` .
@@ -595,7 +596,7 @@ def pop_path(
         *((object_popper,) if descend_objects else ()),
     ]
 
-    if root is ...:
+    if root is UNSET:
         root = doc
 
     parts = jsonp_path(path) if isinstance(path, str) else list(path)
@@ -627,7 +628,7 @@ def pop_path(
                     or not str(ex).startswith("invalid literal for int()"),
                 )
         else:
-            if default is ...:
+            if default is UNSET:
                 raise ResolveError(path, part, i)
 
             return default
