@@ -473,9 +473,17 @@ def keyword(
     """
     Annotate a :term:`dependency` that maps to a different name in the underlying function.
 
-    - The value of a *keyword* `needs` dependency is passed in as *keyword argument*
-      to the underlying function.
-    - For *keyword* to work in `provides`, the operation must be a :term:`returns dictionary`.
+    When used on :term:`needs` dependencies:
+
+    * The value of the ``name`` dependency is read from the `solution`, and then
+    * that value is passed in the function as a *keyword-argument* named ``keyword``.
+
+    When used on :term:`provides` dependencies:
+
+    * The operation must be a :term:`returns dictionary`.
+    * The value keyed with ``keyword`` is read from function's returned dictionary,
+      and then
+    * that value is placed into `solution` named as ``name``.
 
     :param keyword:
         The argument-name corresponding to this named-input.
@@ -872,7 +880,7 @@ def sfx(name, optional: bool = None) -> _Modifier:
 
     """
     return _modifier(
-        name, optional=_Optionals.keyword if optional else None, sideffected=name,
+        name, optional=_Optionals.keyword if optional else None, sideffected=name
     )
 
 
@@ -961,17 +969,16 @@ def sfxed(
         >>> with debug_enabled(True):
         ...     finalize_prices
         FnOp(name='finalize_prices',
-                            needs=[sfxed('ORDER', 'Prices'), sfxed('ORDER', 'VAT')],
-                            op_needs=[sfxed('ORDER', 'Prices'), sfxed('ORDER', 'VAT')],
-                            _fn_needs=['ORDER'],
-                            provides=[sfxed('ORDER', 'Totals')],
-                            op_provides=[sfxed('ORDER', 'Totals')],
-                            _fn_provides=['ORDER'],
-                            fn='finalize_prices')
+             needs=[sfxed('ORDER', 'Prices'), sfxed('ORDER', 'VAT')],
+             _user_needs=[sfxed('ORDER', 'Prices', 'VAT')],
+             _fn_needs=['ORDER'], provides=[sfxed('ORDER', 'Totals')],
+             _user_provides=[sfxed('ORDER', 'Totals')],
+             _fn_provides=['ORDER'],
+             fn='finalize_prices')
 
     Notice that declaring a single *sideffected* with many items in `sfx_list`,
     expands into multiple  *"singular"* ``sideffected`` dependencies in the network
-    (check ``needs`` & ``op_needs`` above).
+    (check ``needs`` vs ``_user_needs`` above).
 
         >>> proc_order = compose('process order', new_order, fill_in_vat, finalize_prices)
         >>> sol = proc_order.compute({
@@ -991,10 +998,10 @@ def sfxed(
         :width: 100%
         :name: sideffecteds
 
-    Notice that although many functions consume & produce the same ``ORDER`` dependency
-    (check ``fn_needs`` & ``fn_provides``, above), something that :orange:`would have formed
-    cycles`, the wrapping operations *need* and *provide* different sideffected instances,
-    breaking the cycles.
+    Notice that although many functions consume & produce the same ``ORDER`` dependency,
+    something that :orange:`would have formed cycles`, the wrapping operations
+    *need* and *provide* different *sideffected* instances,
+    :green:`breaking thus the cycles`.
 
     .. seealso::
         The elaborate example in :ref:`hierarchical-data` section.
