@@ -26,6 +26,7 @@ from .base import (
     Plottable,
     RenArgs,
     aslist,
+    asset,
 )
 from .jetsam import save_jetsam
 from .modifier import dep_renamed
@@ -33,35 +34,6 @@ from .modifier import dep_renamed
 log = logging.getLogger(__name__)
 
 
-class NULL_OP(Operation):
-    """
-    Eliminates same-named operations added later during term:`operation merging`.
-
-    :seealso: :ref:`operation-merging`
-    """
-
-    #: Dummy `provides` for pipeline's "last minute" check not to scream.
-    provides = (None,)
-
-    def __init__(self, name):
-        self.name = name
-
-    def __hash__(self):
-        return hash(self.name)
-
-    def __eq__(self, o):
-        return self.name == o.name
-
-    def __repr__(self):
-        return f"{type(self).__name__}({self.name})"
-
-    def compute(self, *args, **kw):
-        raise AssertionError(f"{self} should have been eliminated!")
-
-    def prepare_plot_args(self, *args, **kw):
-        raise AssertionError(f"{self} should have been eliminated!")
-
-
 def _id_bool(b):
     return hash(bool(b)) + 1
 
@@ -78,6 +50,7 @@ def build_network(
     marshalled=None,
     node_props=None,
     renamer=None,
+    excludes=None,
 ):
     """
     The :term:`network` factory that does :term:`operation merging` before constructing it.
@@ -86,7 +59,9 @@ def build_network(
         see same-named param in :func:`.compose`
     """
     kw = {
-        k: v for k, v in locals().items() if v is not None and k not in ("operations")
+        k: v
+        for k, v in locals().items()
+        if v is not None and k not in ("operations", "excludes")
     }
 
     def proc_op(op, parent=None):
@@ -113,7 +88,7 @@ def build_network(
         #
         if hasattr(op, "fn"):
             op.validate_fn_name()
-        if not getattr(op, "op_provides", op.provides):
+        if not op.provides:
             TypeError(f"`provides` must not be empty!")
 
         return op
@@ -124,7 +99,12 @@ def build_network(
             merge_set.update(proc_op(s, op) for s in op.ops)
         else:
             merge_set.add(proc_op(op))
-    merge_set = iset(i for i in merge_set if not isinstance(i, NULL_OP))
+
+    if excludes is not None:
+        excludes = {op for op in merge_set if op in asset(excludes, "excludes")}
+        if excludes:
+            merge_set = [op for op in merge_set if op not in excludes]
+            log.info("Compose excluded %i operations %s.", len(excludes), excludes)
 
     assert all(bool(n) for n in merge_set)
 
@@ -166,6 +146,7 @@ class Pipeline(Operation):
         marshalled=None,
         node_props=None,
         renamer=None,
+        excludes=None,
     ):
         """
         For arguments, ee :meth:`withset()` & class attributes.
@@ -189,7 +170,14 @@ class Pipeline(Operation):
 
         # Prune network
         self.net = build_network(
-            operations, rescheduled, endured, parallel, marshalled, node_props, renamer,
+            operations,
+            rescheduled,
+            endured,
+            parallel,
+            marshalled,
+            node_props,
+            renamer,
+            excludes,
         )
         self.name, self.needs, self.provides, _aliases = reparse_operation_data(
             self.name, self.net.needs, self.net.provides
@@ -255,10 +243,10 @@ class Pipeline(Operation):
         :param endured:
             applies :term:`endurance` to all contained `operations`
         :param parallel:
-            mark all contained `operations` to be executed in :term:`parallel`
+            (deprecated) mark all contained `operations` to be executed in :term:`parallel`
         :param marshalled:
             mark all contained `operations` to be :term:`marshalled <marshalling>`
-            (usefull when run in `parallel` with a :term:`process pool`).
+            (usefull when run in (deprecated) `parallel` with a :term:`process pool`).
         :param renamer:
             see respective parameter in :meth:`.FnOp.withset()`.
 
@@ -330,7 +318,12 @@ class Pipeline(Operation):
         return plot_args
 
     def compile(
-        self, inputs=None, outputs=UNSET, predicate: "NodePredicate" = UNSET
+        self,
+        inputs=None,
+        outputs=UNSET,
+        recompute_from=None,
+        *,
+        predicate: "NodePredicate" = UNSET,
     ) -> "ExecutionPlan":
         """
         Produce a :term:`plan` for the given args or `outputs`/`predicate` narrowed earlier.
@@ -341,6 +334,8 @@ class Pipeline(Operation):
             A string or a list of strings with all data asked to compute.
             If ``None``, all possible intermediate outputs will be kept.
             If not given, those set by a previous call to :meth:`withset()` or cstor are used.
+        :param recompute_from:
+            Described in :meth:`.Pipeline.compute()`.
         :param predicate:
             Will be stored and applied on the next :meth:`compute()` or :meth:`compile()`.
             If not given, those set by a previous call to :meth:`withset()` or cstor are used.
@@ -358,16 +353,21 @@ class Pipeline(Operation):
             *Unreachable outputs...*
                 if net cannot produce asked `outputs`.
         """
-        outputs = self.outputs if outputs == UNSET else outputs
-        predicate = self.predicate if predicate == UNSET else predicate
+        if outputs == UNSET:
+            outputs = self.outputs
+        if predicate == UNSET:
+            predicate = self.predicate
 
-        return self.net.compile(inputs, outputs, predicate)
+        return self.net.compile(inputs, outputs, recompute_from, predicate=predicate)
 
     def compute(
         self,
-        named_inputs: Mapping = UNSET,
+        named_inputs: Mapping = None,
         outputs: Items = UNSET,
-        predicate: "NodePredicate" = None,
+        recompute_from: Items = None,
+        *,
+        predicate: "NodePredicate" = UNSET,
+        pre_callback=None,
         solution_class: "Type[Solution]" = None,
         layered_solution=None,
     ) -> "Solution":
@@ -382,10 +382,28 @@ class Pipeline(Operation):
             A mapping of names --> values that will be fed to the `needs` of all operations.
             Cloned, not modified.
         :param outputs:
-            A string or a list of strings with all data asked to compute.
-            If ``None``, all intermediate data will be kept.
+            A string or a list of dependencies with all data asked to compute.
+            If ``None``, all possible intermediate outputs will be kept.
+            If not given, those set by a previous call to :meth:`withset()` or cstor are used.
+        :param recompute_from:
+            :term:`recompute` operations downstream from these (string or list) dependencies.
+            In effect, before :term:`compiling <compile>`, it marks all values
+            *strictly downstream (excluding themselves)* from the dependencies
+            listed here, as missing from `named_inputs`.
+
+            * Traversing downstream stops when arriving at any dep in `outputs`.
+            * Any dependencies here unreachable downstreams from values in `named_inputs`
+              are ignored, but logged.
+            * Any dependencies here unreachable upstreams from `outputs` (if given)
+              are ignored, but logged.
+            * Results may differ even if graph is unchanged, in the presence
+              of :term:`overwrite`\\s.
         :param predicate:
             filter-out nodes before compiling
+            If not given, those set by a previous call to :meth:`withset()` or cstor are used.
+        :param pre_callback:
+            If given, the :term:`pre_callback` is called before each operation,
+            with that as argument and solution.
         :param solution_class:
             a custom solution factory to use
         :param layered_solution:
@@ -427,20 +445,22 @@ class Pipeline(Operation):
 
         ok = False
         try:
-            if named_inputs is UNSET:
+            if named_inputs is None:
                 named_inputs = {}
 
             net = self.net  # jetsam
-            outputs = self.outputs if outputs == UNSET else outputs
-            if not predicate:
+            if outputs == UNSET:
+                outputs = self.outputs
+            if predicate == UNSET:
                 predicate = self.predicate
 
             log.info("=== Compiling pipeline(%s) ...", self.name)
-            # # Discover nested inputs given.
-            # plan = net.compile(
-            #     self._nested_inputs_given(named_inputs), outputs, predicate
-            # )
-            plan = net.compile(named_inputs.keys(), outputs, predicate)
+            plan = net.compile(
+                named_inputs.keys(),
+                outputs,
+                recompute_from,
+                predicate=predicate,
+            )
 
             # Restore `abort` flag for next run.
             reset_abort()
@@ -449,6 +469,7 @@ class Pipeline(Operation):
                 named_inputs,
                 outputs,
                 name=self.name,
+                pre_callback=pre_callback,
                 solution_class=solution_class,
                 layered_solution=layered_solution,
             )
@@ -507,6 +528,7 @@ def compose(
     name: Union[str, type(...), None],
     op1: Operation,
     *operations: Operation,
+    excludes=None,
     outputs: Items = None,
     rescheduled=None,
     endured=None,
@@ -531,6 +553,9 @@ def compose(
         syntactically force at least 1 operation
     :param operations:
         each argument should be an operation or pipeline instance
+    :param excludes:
+        A single string or list of operation-names to exclude from the final network
+        (particularly useful when composing existing pipelines).
     :param nest:
         a dictionary or callable corresponding to the `renamer` paremater
         of :meth:`.Pipeline.withset()`, but the calable receives a `ren_args`
@@ -583,10 +608,10 @@ def compose(
     :param endured:
         applies :term:`endurance` to all contained `operations`
     :param parallel:
-        mark all contained `operations` to be executed in :term:`parallel`
+        (deprecated) mark all contained `operations` to be executed in :term:`parallel`
     :param marshalled:
         mark all contained `operations` to be :term:`marshalled <marshalling>`
-        (usefull when run in `parallel` with a :term:`process pool`).
+        (usefull when run in (deprecated) `parallel` with a :term:`process pool`).
     :param node_props:
         Added as-is into NetworkX graph, to provide for filtering
         by :meth:`.Pipeline.withset()`.
@@ -611,11 +636,7 @@ def compose(
     operations = (op1,) + operations
     if not all(isinstance(op, Operation) for op in operations):
         bad_ops = [op for op in operations if not isinstance(op, Operation)]
-        op_names = [op.name for op in operations if isinstance(op, Operation)]
-        raise TypeError(
-            f"Received x{len(bad_ops)} non-Operation instances: {bad_ops}"
-            f"\n  out of: {op_names}"
-        )
+        raise TypeError(f"Received x{len(bad_ops)} non-Operation instances: {bad_ops}")
 
     ## Apply default nesting if user asked just a truthy.
     #
@@ -666,4 +687,5 @@ def compose(
         marshalled=marshalled,
         node_props=node_props,
         renamer=renamer,
+        excludes=excludes,
     )
