@@ -17,6 +17,7 @@ from typing import (
     Mapping,
     NamedTuple,
     Optional,
+    Sequence,
     Tuple,
     Union,
 )
@@ -87,9 +88,7 @@ def _optionalized(graph, data):
 def collect_requirements(graph) -> Tuple[iset, iset]:
     """Collect & split datanodes in (possibly overlapping) `needs`/`provides`."""
     operations = list(yield_ops(graph))
-    provides = iset(
-        p for op in operations for p in getattr(op, "op_provides", op.provides)
-    )
+    provides = iset(p for op in operations for p in op.provides)
     needs = iset(_optionalized(graph, n) for op in operations for n in op.needs)
     provides = iset(provides)
     return needs, provides
@@ -110,7 +109,7 @@ EdgeTraversal = Tuple[str, int]
 
 
 def _yield_also_chained_docs(
-    dig_dag: List[EdgeTraversal], dag, doc: str, stop_set=(),
+    dig_dag: List[EdgeTraversal], dag, doc: str, stop_set=()
 ) -> Iterable[str]:
     """
     Dig the `doc` and its sub/super docs, not recursing in those already in `stop_set`.
@@ -241,6 +240,77 @@ def _topo_sort_nodes(dag) -> iset:
         raise nx.NetworkXUnfeasible(msg).with_traceback(tb)
 
 
+def inputs_for_recompute(
+    graph,
+    inputs: Sequence[str],
+    recompute_from: Sequence[str],
+    recompute_till: Sequence[str] = None,
+) -> Tuple[iset, iset]:
+    """
+    Clears the inputs between `recompute_from >--<= recompute_till` to clear.
+
+    :param graph:
+        MODIFIED, at most 2 helper nodes inserted
+    :param inputs:
+        a sequence
+    :param recompute_from:
+        None or a sequence, including any out-of-graph deps (logged))
+    :param recompute_till:
+        (optional) a sequence, only in-graph deps.
+
+    :return:
+        a 2-tuple with the reduced `inputs` by the dependencies that must
+        be removed from the graph to recompute (along with those dependencies).
+
+    It works by temporarily adding x2 nodes to find and remove the intersection of::
+
+        strict-descendants(recompute_from) & ancestors(recompute_till)
+
+    FIXME: merge recompute() with travesing unsatisfied (see ``test_recompute_NEEDS_FIX``)
+    bc it clears inputs of unsatisfied ops (cannot be replaced later)
+    """
+    START, STOP = "_TMP.RECOMPUTE_FROM", "_TMP.RECOMPUTE_TILL"
+
+    deps = set(yield_datanodes(graph.nodes))
+    recompute_from = iset(recompute_from)  # traversed in logs
+    inputs = iset(inputs)  # returned
+    bad = recompute_from - deps
+    if bad:
+        log.info("... ignoring unknown `recompute_from` dependencies: %s", list(bad))
+        recompute_from = recompute_from & deps  # avoid sideffect in `recompute_from`
+    assert recompute_from, f"Given unknown-only `recompute_from` {locals()}"
+
+    graph.add_edges_from((START, i) for i in recompute_from)
+
+    # strictly-downstreams from START
+    between_deps = iset(nx.descendants(graph, START)) & deps - recompute_from
+
+    if recompute_till:
+        graph.add_edges_from((i, STOP) for i in recompute_till)  # edge reversed!
+
+        # upstreams from STOP
+        upstreams = set(nx.ancestors(graph, STOP)) & deps
+        between_deps &= upstreams
+
+    recomputes = between_deps & inputs
+    new_inputs = iset(inputs) - recomputes
+
+    if log.isEnabledFor(logging.DEBUG):
+        log.debug(
+            "... recompute x%i data%s means deleting x%i inputs%s, to arrive from x%i %s -> x%i %s.",
+            len(between_deps),
+            list(between_deps),
+            len(recomputes),
+            list(recomputes),
+            len(inputs),
+            list(inputs),
+            len(new_inputs),
+            list(new_inputs),
+        )
+
+    return new_inputs, recomputes
+
+
 def unsatisfied_operations(dag, inputs: Iterable) -> Tuple[OpMap, iset]:
     """
     Traverse topologically sorted dag to collect un-satisfied operations.
@@ -275,7 +345,7 @@ def unsatisfied_operations(dag, inputs: Iterable) -> Tuple[OpMap, iset]:
     sorted_nodes = _topo_sort_nodes(dag)
 
     if log.isEnabledFor(logging.DEBUG):
-        log.debug("Topo-sorted nodes: %s", list(yield_node_names(sorted_nodes)))
+        log.debug("...topo-sorted nodes: %s", list(yield_node_names(sorted_nodes)))
     for i, node in enumerate(sorted_nodes):
         if isinstance(node, Operation):
             if not dag.adj[node]:
@@ -313,10 +383,12 @@ class Network(Plottable):
 
     .. attribute:: needs
 
-        the "base", all data-nodes that are not produced by some operation
+        the "base", all data-nodes that are not produced by some operation,
+        decided on construction.
     .. attribute:: provides
 
-        the "base", all data-nodes produced by some operation
+        the "base", all data-nodes produced by some operation.
+        decided on construction.
     """
 
     def __init__(self, *operations, graph=None):
@@ -364,13 +436,14 @@ class Network(Plottable):
         self._cached_plans = {}
 
     def __repr__(self):
-        ops = list(yield_ops(self.graph.nodes))
+        nodes = self.graph.nodes
+        ops = list(yield_ops(nodes))
         steps = (
-            [f"\n  +--{s}" for s in self.graph.nodes]
+            [f"\n  +--{s}" for s in nodes]
             if is_debug()
             else ", ".join(n.name for n in ops)
         )
-        return f"Network(x{len(self.graph.nodes)} nodes, x{len(ops)} ops: {''.join(steps)})"
+        return f"Network(x{len(nodes)} nodes, x{len(ops)} ops: {''.join(steps)})"
 
     def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
         plot_args = plot_args.clone_or_merge_graph(self.graph)
@@ -428,7 +501,7 @@ class Network(Plottable):
         #
         needs = []
         needs_edges = []
-        for n in getattr(operation, "op_needs", operation.needs):
+        for n in operation.needs:
             json_path = get_jsonp(n)
             if json_path:
                 append_subdoc_chain(json_path)
@@ -446,18 +519,19 @@ class Network(Plottable):
             needs.append((n, nkw))
             needs_edges.append((n, operation, ekw))
         graph.add_nodes_from(needs)
-        graph.add_node(operation, **operation.node_props)
+        node_props = getattr(operation, "node_props", None) or {}
+        graph.add_node(operation, **node_props)
         graph.add_edges_from(needs_edges)
 
         ## Prepare inversed-aliases index, used
         #  to label edges reaching to aliased `provides`.
         #
         aliases = getattr(operation, "aliases", None)
-        alias_sources = {v: src for src, v in aliases} if aliases else ()
+        alias_destinations = {v: src for src, v in aliases} if aliases else ()
 
         ## Provides
         #
-        for n in getattr(operation, "op_provides", operation.provides):
+        for n in operation.provides:
             json_path = get_jsonp(n)
             if json_path:
                 append_subdoc_chain(json_path)
@@ -469,9 +543,8 @@ class Network(Plottable):
             if is_implicit(n):
                 kw["implicit"] = True
 
-            if n in alias_sources:
-                src_provide = alias_sources[n]
-                kw["alias_of"] = src_provide
+            if n in alias_destinations:
+                kw["alias_of"] = alias_destinations[n]
 
             graph.add_edge(operation, n, **kw)
 
@@ -652,7 +725,8 @@ class Network(Plottable):
             The original dag, pruned; not broken.
         :param sorted_nodes:
             an :class:`~boltons:boltons.setutils.IndexedSet` with all graph nodes
-            topo-sorted (including pruned ones)
+            topo-sorted (including pruned ones) by execution order & operation-insertion
+            to break ties (see :func:`_topo_sort_nodes()`).
         :param inputs:
             Not used(!), useless inputs will be evicted when the solution is created.
         :param outputs:
@@ -707,7 +781,7 @@ class Network(Plottable):
                 if steps[-1] == dep:
                     # Functions with redundant SFXEDs like ['a', sfxed('a', ...)]??
                     log.warning(
-                        "Skipped dupe step %r @ #%i."
+                        "Skipped adding dupe eviction step %r @ #%i."
                         "\n  (hint: do you have redundant SFXEDs like ['a', sfxed('a', ...)]??)",
                         dep,
                         len(steps),
@@ -716,7 +790,7 @@ class Network(Plottable):
                 if log.isEnabledFor(logging.DEBUG) and dep in steps:
                     # Happens by rule-2 if multiple Ops produce
                     # the same pruned out.
-                    log.debug("Re-evicting %r @ #%i.", dep, len(steps))
+                    log.debug("... re-evicting %r @ #%i.", dep, len(steps))
             steps.append(dep)
 
         steps = []
@@ -776,8 +850,29 @@ class Network(Plottable):
 
         return list(steps)
 
+    def _deps_tuplized(
+        self, deps, arg_name
+    ) -> Tuple[Optional[Tuple[str, ...]], Optional[Tuple[str, ...]]]:
+        """
+        Stabilize None or string/list-of-strings, drop names out of graph.
+
+        :return:
+            a 2-tuple (stable-deps, deps-in-graph) or ``(None, None)``
+        """
+        if deps is None:
+            return None, None
+
+        data_nodes = set(yield_datanodes(self.graph.nodes))
+        deps = tuple(sorted(astuple(deps, arg_name, allowed_types=abc.Collection)))
+        return deps, tuple(d for d in deps if d in data_nodes)
+
     def compile(
-        self, inputs: Items = None, outputs: Items = None, predicate=None
+        self,
+        inputs: Items = None,
+        outputs: Items = None,
+        recompute_from=None,
+        *,
+        predicate=None,
     ) -> "ExecutionPlan":
         """
         Create or get from cache an execution-plan for the given inputs/outputs.
@@ -793,6 +888,8 @@ class Network(Plottable):
             A collection or the name of the output name(s).
             If `None``, all reachable nodes from the given `inputs` are assumed.
             If string, it is converted to a single-element collection.
+        :param recompute_from:
+            Described in :meth:`.Pipeline.compute()`.
         :param predicate:
             the :term:`node predicate` is a 2-argument callable(op, node-data)
             that should return true for nodes to include; if None, all nodes included.
@@ -814,35 +911,31 @@ class Network(Plottable):
 
         ok = False
         try:
-            ## Make a stable cache-key.
+            ## Make a stable cache-key,
+            #  ignoring out-of-graph nodes (2nd results).
             #
-            if inputs is not None:
-                inputs = tuple(
-                    sorted(astuple(inputs, "inputs", allowed_types=abc.Collection))
-                )
-            if outputs is not None:
-                outputs = tuple(
-                    sorted(astuple(outputs, "outputs", allowed_types=abc.Collection))
-                )
+            inputs, k1 = self._deps_tuplized(inputs, "inputs")
+            outputs, k2 = self._deps_tuplized(outputs, "outputs")
+            recompute_from, k3 = self._deps_tuplized(recompute_from, "recompute_from")
             if not predicate:
                 predicate = None
-
-            cache_key = (inputs, outputs, predicate)
+            cache_key = (k1, k2, k3, predicate, is_skip_evictions())
 
             ## Build (or retrieve from cache) execution plan
-            #  for the given inputs & outputs.
+            #  for the given dep-lists (excluding any unknown node-names).
             #
             if cache_key in self._cached_plans:
                 log.debug("... compile cache-hit key: %s", cache_key)
                 plan = self._cached_plans[cache_key]
             else:
-                (
-                    pruned_dag,
-                    sorted_nodes,
-                    needs,
-                    provides,
-                    op_comments,
-                ) = self._prune_graph(inputs, outputs, predicate)
+                if recompute_from:
+                    inputs, recomputes = inputs_for_recompute(
+                        self.graph.copy(), inputs, recompute_from, k2
+                    )
+
+                _prune_results = self._prune_graph(inputs, outputs, predicate)
+                pruned_dag, sorted_nodes, needs, provides, op_comments = _prune_results
+
                 steps = self._build_execution_steps(
                     pruned_dag, sorted_nodes, needs, outputs or ()
                 )
