@@ -41,6 +41,7 @@ import jinja2
 import networkx as nx
 import pydot
 from boltons.iterutils import default_enter, default_exit, get_path, remap
+from boltons.setutils import IndexedSet as iset
 from jinja2.filters import do_truncate
 
 from . import __version__
@@ -197,7 +198,11 @@ def is_nx_node_dependent(graph, nx_node):
 
 # TODO: move to base.py, to reduce fan-in imports (and be frank with module diagram).
 def graphviz_html_string(
-    s, *, repl_nl=None, repl_colon=None, xmltext=None,
+    s,
+    *,
+    repl_nl=None,
+    repl_colon=None,
+    xmltext=None,
 ):
     """
     Workaround *pydot* parsing of node-id & labels by encoding as HTML.
@@ -423,6 +428,8 @@ class Theme:
     """
     The poor man's css-like :term:`plot theme` (see also :class:`.StyleStack`).
 
+    Tip: `Graphviz node-attributes <https://graphviz.org/doc/info/attrs.html>`_
+
     To use the values contained in theme-instances, stack them in a :class:`.StylesStack`,
     and :meth:`.StylesStack.merge` them with :term:`style expansion`\\s
     (read it from :meth:`.StyleStack.expand()`).
@@ -489,7 +496,7 @@ class Theme:
 
     #: Attributes applying to all nodes with ``node [...]`` graphviz construct,
     #: append in graph only if non-empty.
-    node_defaults = {}
+    node_defaults = {"style": ["filled"], "fillcolor": "white"}
     #: Attributes applying to all edges with ``edge [...]`` graphviz construct,
     #: appended in graph only if non-empty.
     edge_defaults = {}
@@ -526,7 +533,7 @@ class Theme:
     kw_data_sideffected = {}
     kw_data_to_evict = {
         "color": Ref("evicted_color"),
-        "style": ["dashed"],
+        "style": ["filled", "dashed"],
         "tooltip": ["(to evict)"],
     }
     ##
@@ -546,7 +553,7 @@ class Theme:
     kw_data_overwritten = {
         "style": ["filled"],
         "fillcolor": Ref("overwrite_color"),
-        "tooltip": ["(overridden)"],
+        "tooltip": ["(overwritten)"],
     }
     kw_data_missing = {
         "fontcolor": Ref("canceled_color"),
@@ -785,7 +792,7 @@ class Theme:
     kw_edge = {"tailport": "s", "headport": "n"}
     kw_edge_tail_op = {}
     kw_edge_head_op = {"arrowtail": "inv", "dir": "back"}
-    kw_edge_optional = {"style": ["dashed",], "tooltip": ["(optional)"]}
+    kw_edge_optional = {"style": ["dashed"], "tooltip": ["(optional)"]}
     kw_edge_sideffect = {"color": Ref("sideffect_color")}
     kw_edge_implicit = {
         lambda pa: (
@@ -1113,7 +1120,7 @@ class StylesStack(NamedTuple):
 
         - Workaround pydot/pydot#228 pydot-cstor not supporting styles-as-lists.
 
-        - Merge tooltip-lists.
+        - Merge tooltip & tooltip lists.
 
         .. theme-expansions-end
         """
@@ -1162,7 +1169,7 @@ class StylesStack(NamedTuple):
         graphviz_style = style.get("style")
         if isinstance(graphviz_style, (list, tuple)):
             ## FIXME: support only plain-strings as graphviz-styles.
-            graphviz_style = ",".join(str(i) for i in set(graphviz_style))
+            graphviz_style = ",".join(str(i) for i in iset(graphviz_style))
             if "," in graphviz_style:
                 graphviz_style = f'"{graphviz_style}"'
             style["style"] = graphviz_style
@@ -1392,7 +1399,7 @@ class Plotter:
         graph = plot_args.graph
         nx_node = plot_args.nx_item
         node_attrs = plot_args.nx_attrs
-        (plottable, _, _, steps, inputs, outputs, solution, *_,) = plot_args
+        (plottable, _, _, steps, inputs, outputs, solution, *_) = plot_args
 
         label_styles = self._new_styles_stack(plot_args)
         if isinstance(nx_node, str):  # DATA
@@ -1472,15 +1479,17 @@ class Plotter:
 
             ## Op-kind
             #
-            if first_solid(is_reschedule_operations(), nx_node.rescheduled):
+            if first_solid(
+                is_reschedule_operations(), getattr(nx_node, "rescheduled", None)
+            ):
                 label_styles.add("kw_op_rescheduled")
-            if first_solid(is_endure_operations(), nx_node.endured):
+            if first_solid(is_endure_operations(), getattr(nx_node, "endured", None)):
                 label_styles.add("kw_op_endured")
-            if first_solid(is_parallel_tasks(), nx_node.parallel):
+            if first_solid(is_parallel_tasks(), getattr(nx_node, "parallel", None)):
                 label_styles.add("kw_op_parallel")
-            if first_solid(is_marshal_tasks(), nx_node.marshalled):
+            if first_solid(is_marshal_tasks(), getattr(nx_node, "marshalled", None)):
                 label_styles.add("kw_op_marshalled")
-            if nx_node.returns_dict:
+            if getattr(nx_node, "returns_dict", None):
                 label_styles.add("kw_op_returns_dict")
 
             ## Op-state
@@ -1519,7 +1528,7 @@ class Plotter:
                 "op_label_template",
                 {
                     "label": _render_template(
-                        theme.op_template, steps=steps, **label_styles.merge(),
+                        theme.op_template, steps=steps, **label_styles.merge()
                     )
                 },
             )
@@ -1529,7 +1538,7 @@ class Plotter:
 
         return pydot.Node(**styles.merge())
 
-    def _build_cluster_path(self, plot_args: PlotArgs, *path,) -> None:
+    def _build_cluster_path(self, plot_args: PlotArgs, *path) -> None:
         """Return the last cluster in the path created"""
         clustered = plot_args.clustered
         root = plot_args.dot
@@ -1894,7 +1903,10 @@ class Plotter:
 
 
 def legend(
-    filename=None, show=None, jupyter_render: Mapping = None, plotter: Plotter = None,
+    filename=None,
+    show=None,
+    jupyter_render: Mapping = None,
+    plotter: Plotter = None,
 ):
     """
     Generate a legend for all plots (see :meth:`.Plottable.plot()` for args)
