@@ -10,11 +10,22 @@ from unittest.mock import MagicMock
 
 import pytest
 
-from graphtik import base, operation, pipeline, planning
+from graphtik import (
+    base,
+    compose,
+    modify,
+    operation,
+    pipeline,
+    planning,
+    sfx,
+    sfxed,
+    vararg,
+    varargs,
+)
 from graphtik.base import Operation
-from graphtik.jetsam import save_jetsam
 from graphtik.config import debug_enabled
 from graphtik.execution import ExecutionPlan, Solution, _OpTask
+from graphtik.jetsam import save_jetsam
 from graphtik.pipeline import Pipeline
 
 
@@ -216,21 +227,20 @@ def test_jetsam_sites_screaming_func(acallable, expected_jetsam):
         (
             lambda: fnt.partial(
                 Pipeline([operation(str)], "name").compute,
-                named_inputs=None,
-                outputs="bad",
+                named_inputs="BOO",
             ),
             "network plan solution pipeline outputs plot_fpath".split(),
         ),
     ]
 )
 def failing_jetsam(request):
-    return request.param
+    acallable, expected_jetsam = request.param
+    return acallable(), expected_jetsam
 
 
 def test_jetsam_sites_scream(failing_jetsam):
     # Check jetsams when the site fails.
     acallable, expected_jetsam = failing_jetsam
-    acallable = acallable()
     with pytest.raises(Exception) as excinfo:
         acallable()
 
@@ -245,7 +255,6 @@ def test_jetsam_sites_scream(failing_jetsam):
 def test_jetsam_saves_plot(failing_jetsam):
     acallable, expected_jetsam = failing_jetsam
     if "plot_fpath" in expected_jetsam:
-        acallable = acallable()
         with debug_enabled(True), pytest.raises(Exception) as excinfo:
             acallable()
 
@@ -255,6 +264,50 @@ def test_jetsam_saves_plot(failing_jetsam):
         fp.unlink(missing_ok=True)
 
 
+def test_jetsam_n_plot_with_DEBUG():
+    pipe = compose(
+        "mix",
+        operation(
+            str,
+            "FUNC",
+            needs=[
+                "a",
+                sfxed("b", "foo", keyword="bb"),
+                modify("c", implicit=1),
+                sfxed("d", "bar", implicit=1),
+                vararg("e"),
+                varargs("f"),
+            ],
+            provides=[
+                "A",
+                sfxed("b", "FOO", keyword="bb"),
+                modify("C", implicit=1),
+                sfxed("d", "BAR", implicit=1),
+                sfx("FOOBAR"),
+            ],
+            aliases={"A": "aaa", "b": "bbb", "C": "ccc", "d": "ddd"},
+        ),
+    )
+
+    with debug_enabled(True), pytest.raises(ValueError, match="^Unsolvable"):
+        pipe.compute()
+    with debug_enabled(True), pytest.raises(
+        ValueError, match="^Failed matching inputs <=> needs"
+    ) as exc:
+        pipe.compute(
+            {
+                "a": 1,
+                sfxed("b", "foo"): 2,
+                "c": 3,
+                sfxed("d", "bar"): 4,
+                "e": 5,
+                "f": [6, 7],
+            }
+        )
+
+    exc.value.jetsam.plot_fpath.unlink()
+
+
 ###############
 ## func_name
 ##
@@ -359,13 +412,13 @@ def test_func_name_partial_args(kw, exp):
         ({"mod": 0, "fqdn": 0, "human": 0}, "_foo"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base._foo"),
         ({"mod": 0, "fqdn": 0, "human": 1}, "_foo(1, a=2, b=3, ...)"),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base._foo(1, a=2, b=3, ...)",),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base._foo(1, a=2, b=3, ...)"),
         ## FQDN = 1
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "_foo"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "test.test_base._foo"),
         ({"mod": 0, "fqdn": 1, "human": 1}, "_foo(1, a=2, b=3, ...)"),
-        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._foo(1, a=2, b=3, ...)",),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._foo(1, a=2, b=3, ...)"),
     ],
 )
 def test_func_name_partial_x2(kw, exp):
@@ -380,13 +433,13 @@ def test_func_name_partial_x2(kw, exp):
         ({"mod": 0, "fqdn": 0, "human": 0}, "foo"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base.foo"),
         ({"mod": 0, "fqdn": 0, "human": 1}, "foo"),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.foo",),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.foo"),
         ## FQDN = 0
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "_Foo.foo"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "test.test_base._Foo.foo"),
         ({"mod": 0, "fqdn": 1, "human": 1}, "_Foo.foo"),
-        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._Foo.foo",),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._Foo.foo"),
     ],
 )
 def test_func_name_class_method(kw, exp):
@@ -401,13 +454,13 @@ def test_func_name_class_method(kw, exp):
         ({"mod": 0, "fqdn": 0, "human": 0}, "foo"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base.foo"),
         ({"mod": 0, "fqdn": 0, "human": 1}, "foo"),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.foo",),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.foo"),
         ## FQDN = 1
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "_Foo.foo"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "test.test_base._Foo.foo"),
         ({"mod": 0, "fqdn": 1, "human": 1}, "_Foo.foo"),
-        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._Foo.foo",),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._Foo.foo"),
     ],
 )
 def test_func_name_object_method(kw, exp):
@@ -422,13 +475,13 @@ def test_func_name_object_method(kw, exp):
         ({"mod": 0, "fqdn": 0, "human": 0}, "foo"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base.foo"),
         ({"mod": 0, "fqdn": 0, "human": 1}, "foo(...)"),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.foo(...)",),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.foo(...)"),
         ## FQDN = 1
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "_Foo.foo"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "test.test_base._Foo.foo"),
         ({"mod": 0, "fqdn": 1, "human": 1}, "_Foo.foo(...)"),
-        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._Foo.foo(...)",),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._Foo.foo(...)"),
     ],
 )
 def test_func_name_partial_method(kw, exp):
@@ -440,10 +493,10 @@ def test_func_name_partial_method(kw, exp):
     [
         ## FQDN = 0
         #
-        ({"mod": 0, "fqdn": 0, "human": 0}, "<lambda>",),
-        ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base.<lambda>",),
-        ({"mod": 0, "fqdn": 0, "human": 1}, "<lambda>",),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.<lambda>",),
+        ({"mod": 0, "fqdn": 0, "human": 0}, "<lambda>"),
+        ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base.<lambda>"),
+        ({"mod": 0, "fqdn": 0, "human": 1}, "<lambda>"),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base.<lambda>"),
         ## FQDN = 1
         #
         (
@@ -488,7 +541,12 @@ def test_func_name_partials_vs_human():
 ## func_source
 ##
 @pytest.mark.parametrize(
-    "fn", [_foo, fnt.partial(_foo), fnt.partial(_foo, 1),],
+    "fn",
+    [
+        _foo,
+        fnt.partial(_foo),
+        fnt.partial(_foo, 1),
+    ],
 )
 def test_func_source_func(fn):
     exp = "def _foo():\n    pass"
@@ -528,7 +586,12 @@ def test_func_source_builtin_human(fn):
 ## func_sourcelines
 ##
 @pytest.mark.parametrize(
-    "fn", [_foo, fnt.partial(_foo), fnt.partial(_foo, 1),],
+    "fn",
+    [
+        _foo,
+        fnt.partial(_foo),
+        fnt.partial(_foo, 1),
+    ],
 )
 def test_func_sourcelines_func(fn):
     exp = "def _foo():\n    pass"
