@@ -13,23 +13,26 @@ from graphtik import (
     NO_RESULT,
     compose,
     modify,
-    planning,
     operation,
     optional,
+    planning,
+    sfx,
+    sfxed,
     vararg,
     varargs,
-    sfxed,
-    sfx,
 )
-from graphtik.base import IncompleteExecutionError
+from graphtik.base import IncompleteExecutionError, UNSET
 from graphtik.config import debug_enabled, evictions_skipped, operations_endured
 
-from .helpers import addall
-
+from .helpers import addall, exe_params
 
 pytestmark = pytest.mark.usefixtures("log_levels")
 
 
+def exe_ops(sol):
+    return [op.name for op in sol.executed]
+
+
 def scream(*args, **kwargs):
     raise AssertionError(f"Must not have run!\n    args: {args}\n  kwargs: {kwargs}")
 
@@ -134,24 +137,31 @@ def test_cycle_tip():
 
 
 def test_aliases(exemethod):
+    provides = ("a", sfxed("s1", "foo"), sfxed("s2", "foo", implicit=1))
     aliased = operation(
         lambda: ("A", "B"),
         name="op1",
-        provides=["a", sfxed("s1", "foo"), sfxed("s2", "foo", implicit=1)],
+        provides=provides,
         aliases={"a": "b", "s1": "S1", "s2": "S2"},
     )
-    assert aliased.provides == ("a", sfxed("s1", "foo"), sfxed("s2", "foo"))
-    assert set(aliased.op_provides) == set(
-        ("a", "b", "S1", "S2", sfxed("s1", "foo"), sfxed("s2", "foo"))
+    assert aliased._user_provides == provides
+    assert tuple(aliased.provides) == (
+        "a",
+        sfxed("s1", "foo"),
+        sfxed("s2", "foo"),
+        "b",
+        "S1",
+        "S2",
     )
 
-    op = compose(
+    pipe = compose(
         "test_net",
         aliased,
         operation(lambda x: x * 2, name="op2", needs="b", provides="c"),
         parallel=exemethod,
     )
-    assert op() == {"a": "A", "s1": "B", "b": "A", "S1": "B", "c": "AA"}
+    assert pipe() == {"a": "A", "s1": "B", "b": "A", "S1": "B", "c": "AA"}
+    assert list(pipe.provides) == [*aliased.provides, "c"]
 
 
 def test_node_predicate_based_prune():
@@ -283,10 +293,10 @@ def test_impossible_outputs():
         operation(name="op2", needs=["aa", "bb"], provides="aabb")(identity),
     )
     with pytest.raises(ValueError, match="Unreachable outputs"):
-        pipeline.compute({"a": 1,}, ["aabb"])
+        pipeline.compute({"a": 1}, ["aabb"])
 
     with pytest.raises(ValueError, match="Unreachable outputs"):
-        pipeline.compute({"a": 1,}, ["aa", "aabb"])
+        pipeline.compute({"a": 1}, ["aa", "aabb"])
 
 
 def test_pruning_not_overrides_given_intermediate(exemethod):
@@ -599,7 +609,7 @@ def test_narrow_and_optionality(reverse):
 
 
 @pytest.fixture
-def quarantine_pipeline(exemethod):
+def quarantine_pipeline():
     @operation(
         rescheduled=1, needs="quarantine", provides=["space", "time"], returns_dict=True
     )
@@ -617,21 +627,21 @@ def quarantine_pipeline(exemethod):
     def read_book(for_how_long):
         return "relaxed", "popular physics"
 
-    pipeline = compose(
-        "covid19", get_out_or_stay_home, exercise, read_book, parallel=exemethod
-    )
+    pipeline = compose("covid19", get_out_or_stay_home, exercise, read_book)
     return pipeline
 
 
-def test_rescheduled_quarantine_doctest(quarantine_pipeline):
-    pipeline = quarantine_pipeline
-    sol = pipeline(quarantine=True)
+def test_rescheduled_quarantine_doctest(quarantine_pipeline, exemethod):
+    pipeline = compose("covid19", quarantine_pipeline, parallel=exemethod)
+
+    sol = pipeline.compute({"quarantine": True})
     assert sol == {
         "quarantine": True,
         "time": "1h",
         "fun": "relaxed",
         "brain": "popular physics",
     }
+
     sol = pipeline(quarantine=False)
     assert sol == {
         "quarantine": False,
@@ -641,10 +651,15 @@ def test_rescheduled_quarantine_doctest(quarantine_pipeline):
     }
 
 
-def test_rescheduled_quarantine_with_overwrites(quarantine_pipeline):
+def test_rescheduled_quarantine_with_overwrites(quarantine_pipeline, exemethod):
     friendly_garden = operation(lambda: "garden", name="friends", provides="space")
 
-    pipeline = compose("quarantine with friends", friendly_garden, quarantine_pipeline)
+    pipeline = compose(
+        "quarantine with friends",
+        friendly_garden,
+        quarantine_pipeline,
+        parallel=exemethod,
+    )
     fun_overwrites = ["relaxed", "refreshed"]
     space_overwrites = ["around the block", "garden"]
 
@@ -830,7 +845,8 @@ def test_skip_eviction_flag():
 
 
 @pytest.mark.parametrize(
-    "endurance, endured", [(None, True), (True, None), (1, 0), (1, 1)],
+    "endurance, endured",
+    [(None, True), (True, None), (1, 0), (1, 1)],
 )
 def test_execution_endurance(exemethod, endurance, endured):
     with operations_endured(endurance):
@@ -872,7 +888,8 @@ def test_execution_endurance(exemethod, endurance, endured):
 
 
 @pytest.mark.parametrize(
-    "resched, rescheduled", [(None, True), (True, None), (1, 0), (1, 1)],
+    "resched, rescheduled",
+    [(None, True), (True, None), (1, 0), (1, 1)],
 )
 def test_rescheduling(exemethod, resched, rescheduled):
     canc = operation(lambda: None, name="canc", needs=["b"], provides="cc")
@@ -927,45 +944,267 @@ def test_rescheduling_NO_RESULT(exemethod):
         assert sol.scream_if_incomplete()
 
 
-def test_jetsam_n_plot_with_DEBUG():
-    pipe = compose(
-        "mix",
-        operation(
-            str,
-            "FUNC",
-            needs=[
-                "a",
-                sfxed("b", "foo", keyword="bb"),
-                modify("c", implicit=1),
-                sfxed("d", "bar", implicit=1),
-                vararg("e"),
-                varargs("f"),
-            ],
-            provides=[
-                "A",
-                sfxed("b", "FOO", keyword="bb"),
-                modify("C", implicit=1),
-                sfxed("d", "BAR", implicit=1),
-                sfx("FOOBAR"),
-            ],
-            aliases={"A": "aaa", "b": "bbb", "C": "ccc", "d": "ddd"},
+def test_pre_callback(quarantine_pipeline, exemethod):
+    pipeline = compose("covid19", quarantine_pipeline, parallel=exemethod)
+    called_ops = []
+
+    def op_called(op_cb):
+        assert op_cb.sol["quarantine"]
+        called_ops.append(op_cb.op.name)
+
+    sol = pipeline.compute({"quarantine": True}, pre_callback=op_called)
+    assert sol == {
+        "quarantine": True,
+        "time": "1h",
+        "fun": "relaxed",
+        "brain": "popular physics",
+    }
+    if exe_params.marshal == 1:
+        # Marshaled `called_ops` is not itself :-)
+        assert called_ops == []
+    else:
+        assert called_ops == ["get_out_or_stay_home", "read_book"]
+
+
+##########
+## Rerun, Replan, Recompute
+##
+
+
+def test_rerun(samplenet):
+    pipe = compose(..., samplenet, excludes="sum_op1")
+    sol = pipe.compute({"c": 3, "d": 4})
+    assert sol == {"c": 3, "d": 4, "sum2": 7, "sum3": 10}
+    exp = sol.copy()
+    assert exe_ops(sol) == ["sum_op2", "sum_op3"]
+
+    ## No recomputes, just sol as input.
+    #
+    with pytest.raises(ValueError, match="Unsolvable graph"):
+        pipe.compute(exp)
+
+    with pytest.raises(ValueError, match="Unsolvable graph"):
+        pipe.compute(exp, recompute_from="sum3")  # It's an output/
+
+    ## Recompute on an output does nothing.
+    #
+    with pytest.raises(ValueError, match="Unsolvable graph"):
+        pipe.compute(exp, recompute_from="sum3")
+
+
+def test_rerun_resched(quarantine_pipeline):
+    ## Produce sample solutions
+    #
+    pipe = quarantine_pipeline
+    sol = pipe.compute({"quarantine": True})
+    assert exe_ops(sol) == ["get_out_or_stay_home", "read_book"]
+    exp_t = sol.copy()
+
+    sol = pipe.compute({"quarantine": False})
+    assert exe_ops(sol) == ["get_out_or_stay_home", "exercise"]
+    exp_f = dict(sol)
+
+    ## No recomputes, just sol as input.
+    #
+    sol = pipe.compute(exp_t)
+    assert sol == exp_t
+    assert exe_ops(sol) == ["get_out_or_stay_home"]
+    sol = pipe.compute({**exp_t, "quarantine": False})
+    assert sol == {**exp_t, **exp_f}
+    assert exe_ops(sol) == ["get_out_or_stay_home", "exercise"]
+
+
+@pytest.fixture
+def recompute_sol(samplenet):
+    pipe = compose(..., samplenet, excludes="sum_op1")
+    sol = pipe.compute({"c": 3, "d": 4}, recompute_from=())
+    assert sol == {"c": 3, "d": 4, "sum2": 7, "sum3": 10}
+    assert exe_ops(sol) == ["sum_op2", "sum_op3"]
+
+    return pipe, sol
+
+
+@pytest.mark.parametrize("outs", [None, UNSET, ()])
+@pytest.mark.parametrize("recomputes", [None, ()])
+def test_recompute_empties(recompute_sol, outs, recomputes):
+    pipe, sol = recompute_sol
+    exp = dict(sol)
+
+    with pytest.raises(ValueError, match="^Unsolvable"):
+        pipe.compute(sol, outputs=outs, recompute_from=recomputes)
+    with pytest.raises(ValueError, match="^Unsolvable"):
+        pipe.compute({}, outputs=outs, recompute_from=recomputes)
+
+
+@pytest.mark.parametrize(
+    "recompute, ops",
+    [
+        ("sum2", ["sum_op3"]),
+        ("c", ["sum_op2", "sum_op3"]),
+        ("d", ["sum_op2", "sum_op3"]),
+    ],
+)
+def test_recompute(samplenet, recompute, ops):
+    pipe = compose(..., samplenet, excludes="sum_op1")
+    sol = pipe.compute({"c": 3, "d": 4})
+    assert sol == {"c": 3, "d": 4, "sum2": 7, "sum3": 10}
+    plan = sol.plan
+    exp = dict(sol)
+    assert exe_ops(sol) == ["sum_op2", "sum_op3"]
+
+    ## Recompute
+    #
+    sol = pipe.compute(exp, recompute_from=recompute)
+    assert sol == exp
+    exp = dict(sol)
+    assert exe_ops(sol) == ops
+
+    ## Replan
+    #
+    sol = plan.execute(exp)
+    assert sol == exp
+    assert exe_ops(sol) == ["sum_op2", "sum_op3"]
+    sol = plan.execute(exp, plan.asked_outs)
+    assert sol == exp
+    assert exe_ops(sol) == ["sum_op2", "sum_op3"]
+
+
+@pytest.mark.parametrize(
+    "recompute, exp_ops",
+    [
+        ("quarantine", ["get_out_or_stay_home", "read_book"]),
+        ("time", ["get_out_or_stay_home", "read_book"]),
+        ("space", ["get_out_or_stay_home", "read_book"]),
+        (
+            ["quarantine", "time", "space"],
+            ["get_out_or_stay_home", "read_book"],
         ),
+    ],
+)
+def test_recompute_resched_true(quarantine_pipeline, recompute, exp_ops):
+    ## Produce sample solutions
+    #
+    pipe = quarantine_pipeline
+    sol = pipe.compute({"quarantine": True})
+    assert exe_ops(sol) == ["get_out_or_stay_home", "read_book"]
+    inp = sol.copy()
+
+    ## Recompute
+    #
+    sol = pipe.compute(inp, recompute_from=recompute)
+    assert sol == inp
+    assert exe_ops(sol) == exp_ops
+
+
+@pytest.mark.parametrize(
+    "recompute, exp_ops",
+    [
+        (
+            "quarantine",
+            ["get_out_or_stay_home", "exercise"],
+        ),
+        (
+            "space",
+            ["get_out_or_stay_home", "exercise"],
+        ),
+        (
+            "time",
+            ["get_out_or_stay_home", "exercise"],
+        ),
+        (
+            ["quarantine", "time"],
+            ["get_out_or_stay_home", "exercise"],
+        ),
+        (
+            ["quarantine", "space"],
+            ["get_out_or_stay_home", "exercise"],
+        ),
+        (
+            ["quarantine", "time", "space"],
+            ["get_out_or_stay_home", "exercise"],
+        ),
+    ],
+)
+def test_recompute_resched_false(quarantine_pipeline, recompute, exp_ops):
+    ## Produce sample solutions
+    #
+    pipe = quarantine_pipeline
+    sol = pipe.compute({"quarantine": False})
+    assert exe_ops(sol) == ["get_out_or_stay_home", "exercise"]
+    inp = sol.copy()
+
+    ## Recompute
+    #
+    sol = pipe.compute(inp, recompute_from=recompute)
+    assert sol == inp
+    assert exe_ops(sol) == exp_ops
+
+
+def test_recompute_till():
+    def by2(n):
+        return 2 * n
+
+    pipe = compose(
+        ...,
+        operation(by2, "f0", "a0", "a1"),
+        operation(by2, "f1", "a1", "a2"),
+        operation(by2, "f2", "a2", "a3"),
+        operation(by2, "f3", "a3", "a4"),
+    )
+    sol = pipe(a0=1)
+    assert exe_ops(sol) == ["f0", "f1", "f2", "f3"]
+    assert sol == {"a0": 1, "a1": 2, "a2": 4, "a3": 8, "a4": 16}
+
+    inp = dict(sol)
+    inp["a1"] = 3
+
+    sol = pipe.compute(inp, outputs="a3", recompute_from="a1")
+    assert exe_ops(sol) == ["f1", "f2"]
+    assert sol == {"a3": 12}
+
+    with evictions_skipped(True):
+        sol = pipe.compute(inp, outputs="a3", recompute_from="a1")
+        sol.plot("t.pdf")
+        assert exe_ops(sol) == ["f1", "f2"]
+        assert sol == {"a0": 1, "a1": 3, "a2": 6, "a3": 12, "a4": 16}
+
+
+def test_recompute_NEEDS_FIX():
+    pipe = compose(
+        ...,
+        operation(str, "f1", "a", "aa"),
+        operation(str, "f2", "b", "bb"),
+        operation(lambda a, b: a + b, "ff", ["aa", "bb"], "c"),
     )
 
-    with debug_enabled(True), pytest.raises(ValueError, match="^Unsolvable"):
-        pipe.compute()
-    with debug_enabled(True), pytest.raises(
-        ValueError, match="^Failed matching inputs <=> needs"
-    ) as exc:
-        pipe.compute(
-            {
-                "a": 1,
-                sfxed("b", "foo"): 2,
-                "c": 3,
-                sfxed("d", "bar"): 4,
-                "e": 5,
-                "f": [6, 7],
-            }
-        )
+    ## Produce sample solution
+    #
+    sol = pipe.compute({"a": "a", "b": "b"})
+    assert sol == {"a": "a", "b": "b", "aa": "a", "bb": "b", "c": "ab"}
+    assert exe_ops(sol) == ["f1", "f2", "ff"]
+    exp = sol.copy()
 
-    exc.value.jetsam.plot_fpath.unlink()
+    del exp["b"]
+    exp["a"] = "A"
+
+    ## Correct results
+    #
+    ok_sol = {"a": "A", "aa": "A", "bb": "b", "c": "Ab"}
+    ok_ops = ["f1", "ff"]
+    sol = pipe.compute(exp, recompute_from="a")
+    assert sol == ok_sol
+    assert exe_ops(sol) == ok_ops
+
+    ## ...but when recomputing also `b`: boom!
+    #
+    sol = pipe.compute(exp, recompute_from=["a", "b"])
+    assert sol == {"a": "A", "aa": "A", "bb": "b", "c": "ab"}
+    assert exe_ops(sol) == ["f1"]
+    ## FIXME: these are the correct recompute results!!
+    #  `bb` already in inputs, `ff` should run to calc `c`.
+    #
+    assert sol != ok_sol
+    assert exe_ops(sol) != ok_ops
+    pytest.xfail(
+        reason="recompute must be incorporated into `unsatisfied_operations()`"
+    )
