@@ -63,8 +63,8 @@ def test_serialize_modifier(ser_method):
         (lambda: sfx("e"), "sfx('e')"),
         (lambda: sfx("e", optional=1), "sfx('e')"),
         (lambda: sfxed("f", "a", "b"), "sfxed('f', 'a', 'b')"),
-        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('f', 'ff')",),
-        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "sfxed('f', 'ff')",),
+        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('f', 'ff')"),
+        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "sfxed('f', 'ff')"),
         (lambda: sfxed("f", "ff", optional=1), "sfxed('f', 'ff')"),
         ## Accessor
         #
@@ -75,7 +75,7 @@ def test_serialize_modifier(ser_method):
         (lambda: vararg("c", accessor=acc), "c"),
         (lambda: varargs("d", acc), "d"),
         (lambda: sfxed("f", "a", "b", accessor=acc), "sfxed('f', 'a', 'b')"),
-        (lambda: sfxed("f", "ff", keyword="F", accessor=acc), "sfxed('f', 'ff')",),
+        (lambda: sfxed("f", "ff", keyword="F", accessor=acc), "sfxed('f', 'ff')"),
         (
             lambda: sfxed("f", "ff", optional=1, keyword="F", accessor=acc),
             "sfxed('f', 'ff')",
@@ -109,8 +109,8 @@ def test_modifs_str(mod, exp):
         (lambda: sfx("e"), "sfx('e')"),
         (lambda: sfx("e", optional=1), "sfx('e'(?))"),
         (lambda: sfxed("f", "a", "b"), "sfxed('f', 'a', 'b')"),
-        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('f'(>'F'), 'ff')",),
-        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "sfxed('f'(?'F'), 'ff')",),
+        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('f'(>'F'), 'ff')"),
+        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "sfxed('f'(?'F'), 'ff')"),
         (lambda: sfxed("f", "ff/", optional=1), "sfxed('f'(?), 'ff/')"),
         (lambda: sfxed("f/", "ff", optional=1), "sfxed('f/'($?), 'ff')"),
         (lambda: sfxed("/f", "ff", optional=1, jsonp=0), "sfxed('/f'(?), 'ff')"),
@@ -133,7 +133,7 @@ def test_modifs_str(mod, exp):
             lambda: sfxed("f", "ff", optional=1, keyword="F", accessor=acc),
             "sfxed('f'($?'F'), 'ff')",
         ),
-        (lambda: sfxed("f", "ff", optional=1, accessor=acc), "sfxed('f'($?), 'ff')",),
+        (lambda: sfxed("f", "ff", optional=1, accessor=acc), "sfxed('f'($?), 'ff')"),
         (lambda: sfxed_vararg("f", "a", accessor=acc), "sfxed('f'($*), 'a')"),
         (
             lambda: sfxed_varargs("f", "a", "b", accessor=acc),
@@ -173,7 +173,7 @@ def test_modifs_repr(mod, exp, ser_method):
         (lambda: sfx("e"), "sfx('e')"),
         (lambda: sfx("e", optional=1), "sfx('e', 1)"),
         (lambda: sfxed("f", "a", "b"), "sfxed('f', 'a', 'b')"),
-        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('f', 'ff', keyword='F')",),
+        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('f', 'ff', keyword='F')"),
         (
             lambda: sfxed("f", "ff", optional=1, keyword="F"),
             "sfxed('f', 'ff', keyword='F', optional=1)",
@@ -240,13 +240,10 @@ def test_sideffected_bad(call, exp):
         (lambda: varargs("/d"), "'p./d'($+)"),
         (lambda: sfx("e"), "sfx('p.e')"),
         (lambda: sfx("e", optional=1), "sfx('p.e'(?))"),
-        (lambda: sfxed("f", "a", "b"), "sfxed('p.f', 'a', 'b')",),
-        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('p.f'(>'F'), 'ff')",),
-        (
-            lambda: sfxed("f", "ff", optional=1, keyword="F"),
-            "sfxed('p.f'(?'F'), 'ff')",
-        ),
-        (lambda: sfxed("f", "ff", optional=1), "sfxed('p.f'(?'f'), 'ff')",),
+        (lambda: sfxed("f", "a", "b"), "sfxed('p.f', 'a', 'b')"),
+        (lambda: sfxed("f", "ff", keyword="F"), "sfxed('p.f'(>'F'), 'ff')"),
+        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "sfxed('p.f'(?'F'), 'ff')"),
+        (lambda: sfxed("f", "ff", optional=1), "sfxed('p.f'(?'f'), 'ff')"),
         (
             lambda: sfxed("f", "ff", optional=1, accessor=acc),
             "sfxed('p.f'($?'f'), 'ff')",
@@ -284,7 +281,7 @@ def test_modifs_rename_fn(mod, exp, ser_method):
         (lambda: vararg("c"), "'D'(*)"),
         (lambda: varargs("d"), "'D'(+)"),
         (lambda: sfx("e"), "sfx('D')"),
-        (lambda: sfxed("f", "a", "b", optional=1,), "sfxed('D'(?'f'), 'a', 'b')",),
+        (lambda: sfxed("f", "a", "b", optional=1), "sfxed('D'(?'f'), 'a', 'b')"),
         (
             lambda: sfxed("f", "a", "b", optional=1, keyword="F"),
             "sfxed('D'(?'F'), 'a', 'b')",
@@ -304,19 +301,16 @@ def test_modifs_rename_str(mod, exp, ser_method):
         (lambda: varargs("d"), "'d'(+)"),
         (lambda: sfx("e", optional=1), "sfx('e'(?))"),
         (lambda: sfxed("f", "a", "b"), "'f'"),
-        (lambda: sfxed("f", "ff", keyword="F"), "'f'(>'F')",),
-        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "'f'(?'F')",),
+        (lambda: sfxed("f", "ff", keyword="F"), "'f'(>'F')"),
+        (lambda: sfxed("f", "ff", optional=1, keyword="F"), "'f'(?'F')"),
         (lambda: sfxed("f", "ff", optional=1), "'f'(?)"),
         (lambda: sfxed_vararg("f", "a"), "'f'(*)"),
         (lambda: sfxed_varargs("f", "a", "b"), "'f'(+)"),
         # Accessor
         (lambda: varargs("d", acc), "'d'($+)"),
         (lambda: sfxed("f", "a", "b", accessor=acc), "'f'($)"),
-        (lambda: sfxed("f", "ff", keyword="F", accessor=acc), "'f'($>'F')",),
-        (
-            lambda: sfxed("f", "ff", optional=1, keyword="F", accessor=acc),
-            "'f'($?'F')",
-        ),
+        (lambda: sfxed("f", "ff", keyword="F", accessor=acc), "'f'($>'F')"),
+        (lambda: sfxed("f", "ff", optional=1, keyword="F", accessor=acc), "'f'($?'F')"),
         (lambda: sfxed("f", "ff", optional=1, accessor=acc), "'f'($?)"),
         (lambda: sfxed_vararg("f", "a", accessor=acc), "'f'($*)"),
         (lambda: sfxed_varargs("f", "a", "b", accessor=acc), "'f'($+)"),
@@ -341,8 +335,7 @@ def test_sideffected_singularized(mod, exp):
     assert got == exp
 
 
-@pytest.mark.parametrize("modif", [sfxed, modify])
-def test_implicit(modif, ser_method):
+def test_implicit(ser_method):
     assert is_implicit("a") is None
     m = sfxed("a", "b")
     assert is_implicit(m) is None
