@@ -379,8 +379,14 @@ def test_as_renames(inp, exp):
                 r"The `aliases` \['b'-->'B'\] rename non-existent provides in \['a'\]"
             ),
         ),
-        ((sfx("a"), {sfx("a"): "a"}), ValueError("must not contain `sideffects"),),
-        (("a", {"a": sfx("AA")}), ValueError("must not contain `sideffects"),),
+        (
+            (sfx("a"), {sfx("a"): "a"}),
+            ValueError("must not contain `sideffects"),
+        ),
+        (
+            ("a", {"a": sfx("AA")}),
+            ValueError("must not contain `sideffects"),
+        ),
         (
             (["a", "b"], {"a": "b"}),
             ValueError(r"clash with existing provides in \['a', 'b'\]"),
@@ -394,10 +400,36 @@ def test_func_op_validation_aliases_BAD(prov_aliases, ex):
 
 def test_provides_aliases():
     op = operation(str, name="t", needs="s", provides="a", aliases={"a": "aa"})
-    assert op.op_provides == {"a", "aa"}
+    assert op.provides == {"a", "aa"}
     assert op.compute({"s": "k"}) == {"a": "k", "aa": "k"}
 
 
+def test_sfxed_needs_in_pipeline():
+    deps = (sfxed("a", "A", "B"), sfxed("a", "A", "C"), "c", "c")
+    op = operation(str, "hh", needs=deps)
+
+    singularized = (sfxed("a", "A"), sfxed("a", "B"), sfxed("a", "C"), "c")
+    assert op.needs == singularized
+    assert op._user_needs == deps
+    assert op._fn_needs == ("a", "c", "c")
+
+    pipe = compose(..., op)
+    assert pipe.needs == singularized
+
+
+def test_sfxed_provides_in_pipeline():
+    deps = (sfxed("a", "A", "B"), sfxed("a", "A", "C"), "c", "c")
+    op = operation(str, "hh", provides=deps)
+
+    singularized = (sfxed("a", "A"), sfxed("a", "B"), sfxed("a", "C"), "c")
+    assert op.provides == singularized
+    assert op._user_provides == deps
+    assert op._fn_provides == ("a", "c", "c")
+
+    pipe = compose(..., op)
+    assert pipe.provides == singularized
+
+
 @pytest.mark.parametrize("rescheduled", [0, 1])
 def test_reschedule_more_outs(rescheduled, caplog):
     op = operation(
@@ -586,19 +618,23 @@ def test_serialize_pipeline(samplenet, ser_method):
 
 def test_non_op_given():
     with pytest.raises(
-        TypeError, match=r"(?s)Received x1 non-Operation instances.+\[1\].+\['b', 'a'\]"
+        TypeError, match=r"(?s)Received x1 non-Operation instances: \[1\]"
     ):
         compose("", operation(None, name="b"), 1, operation(None, name="a"))
     with pytest.raises(
         TypeError,
-        match=r"(?s)Received x1 non-Operation instances.+'noop'.+\['b', 'a'\]",
+        match=r"(?s)Received x2 non-Operation instances: \['noop', <function .+>\]",
     ):
-        compose("", "noop", operation(None, name="b"), operation(None, name="a"))
+        compose("", "noop", operation(None, name="b"), lambda: None)
 
 
 def test_op_rename():
     op = operation(
-        str, name="op1", needs=sfx("a"), provides=["a", sfx("b")], aliases=[("a", "b")],
+        str,
+        name="op1",
+        needs=sfx("a"),
+        provides=["a", sfx("b")],
+        aliases=[("a", "b")],
     )
 
     def renamer(na):
@@ -610,7 +646,7 @@ def test_op_rename():
     got = str(ren)
     assert got == (
         """
-    FnOp(name='PP.op1', needs=[sfx('PP.a')], provides=['PP.a', sfx('PP.b')], aliases=[('PP.a', 'PP.b')], fn='str')
+    FnOp(name='PP.op1', needs=[sfx('PP.a')], provides=['PP.a', sfx('PP.b'), 'PP.b'], aliases=[('PP.a', 'PP.b')], fn='str')
         """.strip()
     )
 
@@ -635,7 +671,7 @@ def test_op_rename_parts():
         """
         FnOp(name='op1',
             needs=[sfx('a/b'), '/PP.a/PP.b'($)],
-            provides=['PP.b/PP.c'($), sfxed('PP.d/PP.e/PP.f'($), 'k/l')],
+            provides=['PP.b/PP.c'($), sfxed('PP.d/PP.e/PP.f'($), 'k/l'), '/PP.b/PP.t'($)],
             aliases=[('PP.b/PP.c'($), '/PP.b/PP.t'($))], fn='str')
         """,
     )
@@ -670,7 +706,7 @@ def test_pipe_rename():
     assert got == oneliner(
         """
         [FnOp(name='PP.op1', needs=[sfx('PP.a')], fn='str'),
-         FnOp(name='PP.op2', needs=[sfx('PP.a')], provides=['PP.a', sfx('PP.b')],
+         FnOp(name='PP.op2', needs=[sfx('PP.a')], provides=['PP.a', sfx('PP.b'), 'PP.b'],
          aliases=[('PP.a', 'PP.b')], fn='str')]
         """
     )
@@ -678,13 +714,18 @@ def test_pipe_rename():
     ## Check dictionary with callables
     #
     ren = pipe.withset(
-        renamer={"op1": lambda n: "OP1", "op2": False, "a": optional("a"), "b": "B",}
+        renamer={
+            "op1": lambda n: "OP1",
+            "op2": False,
+            "a": optional("a"),
+            "b": "B",
+        }
     )
     got = str(ren.ops)
     assert got == oneliner(
         """
         [FnOp(name='OP1', needs=[sfx('a')], fn='str'),
-         FnOp(name='op2', needs=[sfx('a')], provides=['a'(?), sfx('b')],
+         FnOp(name='op2', needs=[sfx('a')], provides=['a'(?), sfx('b'), 'B'],
          aliases=[('a'(?), 'B')], fn='str')]
         """
     )
